@@ -13,6 +13,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from boto import exception as boto_exception
 from neutronclient.common import exceptions as neutron_exceptions
 from saharaclient.api import base as saharaclient_base
 
@@ -49,7 +50,7 @@ class QuotaMixin(SynchronizedDeletion):
 
 # HEAT
 
-@base.resource("heat", "stacks", order=100)
+@base.resource("heat", "stacks", order=100, tenant_resource=True)
 class HeatStack(base.ResourceManager):
     pass
 
@@ -61,7 +62,10 @@ _nova_order = get_order(200)
 
 @base.resource("nova", "servers", order=next(_nova_order))
 class NovaServer(base.ResourceManager):
-    pass
+    def delete(self):
+        if getattr(self.raw_resource, "OS-EXT-STS:locked", False):
+            self.raw_resource.unlock()
+        super(NovaServer, self).delete()
 
 
 @base.resource("nova", "keypairs", order=next(_nova_order))
@@ -83,6 +87,56 @@ class NovaQuotas(QuotaMixin, base.ResourceManager):
     pass
 
 
+@base.resource("nova", "floating_ips_bulk", order=next(_nova_order),
+               admin_required=True)
+class NovaFloatingIpsBulk(SynchronizedDeletion, base.ResourceManager):
+
+    def id(self):
+        return self.raw_resource.address
+
+    def list(self):
+        return [floating_ip for floating_ip in self._manager().list()
+                if floating_ip.pool.startswith("rally_fip_pool_")]
+
+
+# EC2
+
+_ec2_order = get_order(250)
+
+
+class EC2Mixin(object):
+
+    def _manager(self):
+        return getattr(self.user, self._service)()
+
+
+@base.resource("ec2", "servers", order=next(_ec2_order))
+class EC2Server(EC2Mixin, base.ResourceManager):
+
+    def is_deleted(self):
+        try:
+            instances = self._manager().get_only_instances(
+                instance_ids=[self.id()])
+        except boto_exception.EC2ResponseError as e:
+            # NOTE(wtakase): Nova EC2 API returns 'InvalidInstanceID.NotFound'
+            #                if instance not found. In this case, we consider
+            #                instance has already been deleted.
+            return getattr(e, "error_code") == "InvalidInstanceID.NotFound"
+
+        # NOTE(wtakase): After instance deletion, instance can be 'terminated'
+        #                state. If all instance states are 'terminated', this
+        #                returns True. And if get_only_instaces() returns empty
+        #                list, this also returns True because we consider
+        #                instance has already been deleted.
+        return all(map(lambda i: i.state == "terminated", instances))
+
+    def delete(self):
+        self._manager().terminate_instances(instance_ids=[self.id()])
+
+    def list(self):
+        return self._manager().get_only_instances()
+
+
 # NEUTRON
 
 _neutron_order = get_order(300)
@@ -306,6 +360,53 @@ class DesignateServer(SynchronizedDeletion, base.ResourceManager):
     pass
 
 
+# SWIFT
+
+_swift_order = get_order(1000)
+
+
+class SwiftMixin(SynchronizedDeletion, base.ResourceManager):
+
+    def _manager(self):
+        client = self._admin_required and self.admin or self.user
+        return getattr(client, self._service)()
+
+    def id(self):
+        return self.raw_resource
+
+    def delete(self):
+        delete_method = getattr(self._manager(), "delete_%s" % self._resource)
+        # NOTE(weiwu): *self.raw_resource is required because for deleting
+        # container we are passing only container name, to delete object we
+        # should pass as first argument container and second is object name.
+        delete_method(*self.raw_resource)
+
+
+@base.resource("swift", "object", order=next(_swift_order),
+               tenant_resource=True)
+class SwiftObject(SwiftMixin):
+
+    def list(self):
+        object_list = []
+        containers = self._manager().get_account(full_listing=True)[1]
+        for con in containers:
+            objects = self._manager().get_container(con["name"],
+                                                    full_listing=True)[1]
+            for obj in objects:
+                raw_resource = [con["name"], obj["name"]]
+                object_list.append(raw_resource)
+        return object_list
+
+
+@base.resource("swift", "container", order=next(_swift_order),
+               tenant_resource=True)
+class SwiftContainer(SwiftMixin):
+
+    def list(self):
+        containers = self._manager().get_account(full_listing=True)[1]
+        return [[con["name"]] for con in containers]
+
+
 # MISTRAL
 
 @base.resource("mistral", "workbooks", order=1100, tenant_resource=True)
@@ -314,6 +415,25 @@ class MistralWorkbooks(SynchronizedDeletion, base.ResourceManager):
         self._manager().delete(self.raw_resource.name)
 
 
+# MURANO
+
+_murano_order = get_order(1200)
+
+
+@base.resource("murano", "environments", tenant_resource=True,
+               order=next(_murano_order))
+class MuranoEnvironments(base.ResourceManager):
+    pass
+
+
+@base.resource("murano", "packages", tenant_resource=True,
+               order=next(_murano_order))
+class MuranoPackages(base.ResourceManager):
+    def list(self):
+        return filter(lambda x: x.name != "Core library",
+                      super(MuranoPackages, self).list())
+
+
 # KEYSTONE
 
 _keystone_order = get_order(9000)
