@@ -22,6 +22,7 @@ import jsonschema
 import six
 
 from rally.benchmark.context import base as base_ctx
+from rally.benchmark.context import existing_users as existing_users_ctx
 from rally.benchmark.context import users as users_ctx
 from rally.benchmark.runners import base as base_runner
 from rally.benchmark.scenarios import base as base_scenario
@@ -107,7 +108,7 @@ class BenchmarkEngine(object):
         self.config = config
         self.task = task
         self.admin = admin and objects.Endpoint(**admin) or None
-        self.users = map(lambda u: objects.Endpoint(**u), users or [])
+        self.existing_users = users or []
         self.abort_on_sla_failure = abort_on_sla_failure
 
     @rutils.log_task_wrapper(LOG.info, _("Task validation check cloud."))
@@ -153,25 +154,38 @@ class BenchmarkEngine(object):
                   "config": kwargs, "reason": six.text_type(e)}
             raise exceptions.InvalidBenchmarkConfig(**kw)
 
+    def _get_user_ctx_for_validation(self, context):
+        if self.existing_users:
+            context["config"] = {"existing_users": self.existing_users}
+            user_context = existing_users_ctx.ExistingUsers(context)
+        else:
+            user_context = users_ctx.UserGenerator(context)
+
+        return user_context
+
     @rutils.log_task_wrapper(LOG.info, _("Task validation of semantic."))
     def _validate_config_semantic(self, config):
         self._check_cloud()
 
-        # NOTE(boris-42): In future we will have more complex context, because
-        #                 we will have pre-created users mode as well.
         context = {"task": self.task, "admin": {"endpoint": self.admin}}
         deployment = objects.Deployment.get(self.task["deployment_uuid"])
 
-        with users_ctx.UserGenerator(context) as ctx:
+        # TODO(boris-42): It's quite hard at the moment to validate case
+        #                 when both user context and existing_users are
+        #                 specified. So after switching to plugin base
+        #                 and refactoring validation mechanism this place
+        #                 will be replaced
+        with self._get_user_ctx_for_validation(context) as ctx:
             ctx.setup()
             admin = osclients.Clients(self.admin)
             user = osclients.Clients(context["users"][0]["endpoint"])
 
-            for name, values in six.iteritems(config):
-                for pos, kwargs in enumerate(values):
-                    self._validate_config_semantic_helper(admin, user, name,
-                                                          pos, deployment,
-                                                          kwargs)
+            for u in context["users"]:
+                user = osclients.Clients(u["endpoint"])
+                for name, values in six.iteritems(config):
+                    for pos, kwargs in enumerate(values):
+                        self._validate_config_semantic_helper(
+                            admin, user, name, pos, deployment, kwargs)
 
     @rutils.log_task_wrapper(LOG.info, _("Task validation."))
     def validate(self):
@@ -195,7 +209,11 @@ class BenchmarkEngine(object):
 
     def _prepare_context(self, context, name, endpoint):
         scenario_context = base_scenario.Scenario.meta(name, "context")
-        scenario_context.setdefault("users", {})
+        if self.existing_users and "users" not in context:
+            scenario_context.setdefault("existing_users", self.existing_users)
+        elif "users" not in context:
+            scenario_context.setdefault("users", {})
+
         scenario_context.update(context)
         context_obj = {
             "task": self.task,
@@ -223,9 +241,10 @@ class BenchmarkEngine(object):
                          % json.dumps(key, indent=2))
                 runner = self._get_runner(kw)
                 is_done = threading.Event()
+                unexpected_failure = {}
                 consumer = threading.Thread(
                     target=self.consume_results,
-                    args=(key, self.task, is_done, runner))
+                    args=(key, self.task, is_done, unexpected_failure, runner))
                 consumer.start()
                 context_obj = self._prepare_context(kw.get("context", {}),
                                                     name, self.admin)
@@ -238,13 +257,14 @@ class BenchmarkEngine(object):
                                                        kw.get("args", {}))
                 except Exception as e:
                     LOG.exception(e)
+                    unexpected_failure["exc"] = e
                 finally:
                     self.full_duration = timer.duration()
                     is_done.set()
                     consumer.join()
         self.task.update_status(consts.TaskStatus.FINISHED)
 
-    def consume_results(self, key, task, is_done, runner):
+    def consume_results(self, key, task, is_done, unexpected_failure, runner):
         """Consume scenario runner results from queue and send them to db.
 
         Has to be run from different thread simultaneously with the runner.run
@@ -254,6 +274,8 @@ class BenchmarkEngine(object):
         :param task: Running task
         :param is_done: Event which is set from the runner thread after the
                         runner finishes it's work.
+        :param unexpected_failure: Dictionary object with information about
+                                   unexpected exception.
         :param runner: ScenarioRunner object that was used to run a task
         """
         results = []
@@ -264,12 +286,16 @@ class BenchmarkEngine(object):
                 results.append(result)
                 success = sla_checker.add_iteration(result)
                 if self.abort_on_sla_failure and not success:
+                    sla_checker.set_aborted()
                     runner.abort()
             elif is_done.isSet():
                 break
             else:
                 time.sleep(0.1)
 
+            if unexpected_failure.get("exc"):
+                sla_checker.set_unexpected_failure(unexpected_failure["exc"])
+
         task.append_results(key, {"raw": results,
                                   "load_duration": self.duration,
                                   "full_duration": self.full_duration,
