@@ -155,7 +155,7 @@ def _process_atomic(result, data):
     #                   "values": [[order, $atomic_actions.duration
     #                              if not $error else 0], ...}]
     #
-    #                 Order of actions in "atomic_action" is similiar for
+    #                 Order of actions in "atomic_action" is similar for
     #                 all iteration. So we should take first non "error"
     #                 iteration. And get in atomitc_iter list:
     #                 [{"key": "action", "values":[]}]
@@ -166,7 +166,7 @@ def _process_atomic(result, data):
                             for a in row["atomic_actions"]]
             break
 
-    # NOTE(boris-42): pie is similiar to stacked_area, only difference is in
+    # NOTE(boris-42): pie is similar to stacked_area, only difference is in
     #                 structure of values. In case of $error we shouldn't put
     #                 anything in pie. In case of non error we should put just
     #                 $atomic_actions.duration (without order)
@@ -234,14 +234,15 @@ def _get_atomic_action_durations(result):
         if durations:
             data = [action,
                     round(min(durations), 3),
-                    round(utils.mean(durations), 3),
-                    round(max(durations), 3),
+                    round(utils.median(durations), 3),
                     round(utils.percentile(durations, 0.90), 3),
                     round(utils.percentile(durations, 0.95), 3),
+                    round(max(durations), 3),
+                    round(utils.mean(durations), 3),
                     "%.1f%%" % (len(durations) * 100.0 / len(raw)),
                     len(raw)]
         else:
-            data = [action, None, None, None, None, None, 0, len(raw)]
+            data = [action, None, None, None, None, None, None, 0, len(raw)]
 
         # Save 'total' - it must be appended last
         if action == "total":
@@ -261,10 +262,11 @@ def _process_results(results):
     for result in results:
         table_cols = ["Action",
                       "Min (sec)",
-                      "Avg (sec)",
+                      "Median (sec)",
+                      "90%ile (sec)",
+                      "95%ile (sec)",
                       "Max (sec)",
-                      "90 percentile",
-                      "95 percentile",
+                      "Avg (sec)",
                       "Success",
                       "Count"]
         table_rows = _get_atomic_action_durations(result)
