@@ -243,20 +243,24 @@ class ScenarioRunner(object):
         """Abort the execution of further benchmark scenario iterations."""
         self.aborted.set()
 
-    def _create_process_pool(self, processes_to_start, worker_process,
+    @staticmethod
+    def _create_process_pool(processes_to_start, worker_process,
                              worker_args_gen):
         """Create a pool of processes with some defined target function.
 
         :param processes_to_start: number of processes to create in the pool
         :param worker_process: target function for all processes in the pool
-        :param worker_args_gen: generator of arguments for the target funciton
+        :param worker_args_gen: generator of arguments for the target function
         :returns: the process pool as a deque
         """
         process_pool = collections.deque()
 
         for i in range(processes_to_start):
+            kwrgs = {"processes_to_start": processes_to_start,
+                     "processes_counter": i}
             process = multiprocessing.Process(target=worker_process,
-                                              args=next(worker_args_gen))
+                                              args=next(worker_args_gen),
+                                              kwargs={"info": kwrgs})
             process.start()
             process_pool.append(process)
 
