@@ -19,6 +19,7 @@ import itertools
 import random
 import time
 
+from rally.benchmark import functional
 from rally.common import costilius
 from rally.common import log as logging
 from rally.common import utils
@@ -45,13 +46,13 @@ def scenario(context=None):
     return wrapper
 
 
-class Scenario(object):
+class Scenario(functional.FunctionalMixin):
     """This is base class for any benchmark scenario.
 
        You should create subclass of this class. And your test scenarios will
        be auto discoverable and you will be able to specify it in test config.
     """
-    RESOURCE_NAME_PREFIX = ""
+    RESOURCE_NAME_PREFIX = "rally_"
     RESOURCE_NAME_LENGTH = 10
 
     def __init__(self, context=None, admin_clients=None, clients=None):
@@ -182,26 +183,32 @@ class Scenario(object):
             return False
         return Scenario.meta(cls, "is_scenario", method_name, default=False)
 
-    def clients(self, client_type):
+    def clients(self, client_type, version=None):
         """Returns a python openstack client of the requested type.
 
         The client will be that for one of the temporary non-administrator
         users created before the benchmark launch.
 
         :param client_type: Client type ("nova"/"glance" etc.)
+        :param version: client version ("1"/"2" etc.)
 
         :returns: Standard python OpenStack client instance
         """
-        return getattr(self._clients, client_type)()
+        client = getattr(self._clients, client_type)
 
-    def admin_clients(self, client_type):
+        return client(version) if version is not None else client()
+
+    def admin_clients(self, client_type, version=None):
         """Returns a python admin openstack client of the requested type.
 
         :param client_type: Client type ("nova"/"glance" etc.)
+        :param version: client version ("1"/"2" etc.)
 
         :returns: Python openstack client object
         """
-        return getattr(self._admin_clients, client_type)()
+        client = getattr(self._admin_clients, client_type)
+
+        return client(version) if version is not None else client()
 
     def sleep_between(self, min_sleep, max_sleep):
         """Performs a time.sleep() call for a random amount of seconds.
@@ -261,7 +268,7 @@ def atomic_action_timer(name):
 class AtomicAction(utils.Timer):
     """A class to measure the duration of atomic operations
 
-    This would simplify the way measure atomic opeation duration
+    This would simplify the way measure atomic operation duration
     in certain cases. For example if we want to get the duration
     for each operation which runs in an iteration
     for i in range(repetitions):
