@@ -21,6 +21,7 @@ from rally.benchmark.scenarios.nova import utils
 from rally.benchmark.scenarios import utils as scenario_utils
 from rally.benchmark import types as types
 from rally.benchmark import validation
+from rally.benchmark.wrappers import network as network_wrapper
 from rally.common import log as logging
 from rally import consts
 from rally import exceptions as rally_exceptions
@@ -172,6 +173,37 @@ class NovaServers(utils.NovaScenario,
             action()
         self._delete_server(server, force=force_delete)
 
+    @types.set(image=types.ImageResourceType,
+               flavor=types.FlavorResourceType)
+    @validation.image_valid_on_flavor("flavor", "image")
+    @validation.required_services(consts.Service.NOVA)
+    @validation.required_openstack(users=True)
+    @base.scenario(context={"cleanup": ["nova"]})
+    def boot_lock_unlock_and_delete(self, image, flavor,
+                                    min_sleep=0, max_sleep=0,
+                                    force_delete=False,
+                                    **kwargs):
+        """Boot a server, lock it, then unlock and delete it.
+
+        Optional 'min_sleep' and 'max_sleep' parameters allow the
+        scenario to simulate a pause between locking and unlocking the
+        server (of random duration from min_sleep to max_sleep).
+
+        :param image: image to be used to boot an instance
+        :param flavor: flavor to be used to boot an instance
+        :param min_sleep: Minimum sleep time between locking and unlocking
+                          in seconds
+        :param max_sleep: Maximum sleep time between locking and unlocking
+                          in seconds
+        :param force_delete: True if force_delete should be used
+        :param kwargs: Optional additional arguments for server creation
+        """
+        server = self._boot_server(image, flavor, **kwargs)
+        self._lock_server(server)
+        self.sleep_between(min_sleep, max_sleep)
+        self._unlock_server(server)
+        self._delete_server(server, force=force_delete)
+
     @types.set(image=types.ImageResourceType,
                flavor=types.FlavorResourceType)
     @validation.image_valid_on_flavor("flavor", "image")
@@ -292,8 +324,8 @@ class NovaServers(utils.NovaScenario,
                       force_delete=False, **kwargs):
         """Boot a server, then resize and delete it.
 
-        The scenario first creates a volume and then a server.
-        Assumes that cleanup is done elsewhere.
+        This test will confirm the resize by default,
+        or revert the resize if confirm is set to false.
 
         :param image: image to be used to boot an instance
         :param flavor: flavor to be used to boot an instance
@@ -311,6 +343,66 @@ class NovaServers(utils.NovaScenario,
             self._resize_revert(server)
         self._delete_server(server, force=force_delete)
 
+    @types.set(image=types.ImageResourceType,
+               flavor=types.FlavorResourceType)
+    @validation.image_valid_on_flavor("flavor", "image")
+    @validation.required_services(consts.Service.NOVA)
+    @validation.required_openstack(users=True)
+    @base.scenario(context={"cleanup": ["nova"]})
+    def suspend_and_resume_server(self, image, flavor,
+                                  force_delete=False, **kwargs):
+        """Create a server, suspend, resume and then delete it
+
+        :param image: image to be used to boot an instance
+        :param flavor: flavor to be used to boot an instance
+        :param force_delete: True if force_delete should be used
+        :param kwargs: Optional additional arguments for server creation
+        """
+        server = self._boot_server(image, flavor, **kwargs)
+        self._suspend_server(server)
+        self._resume_server(server)
+        self._delete_server(server, force=force_delete)
+
+    @types.set(image=types.ImageResourceType,
+               flavor=types.FlavorResourceType)
+    @validation.image_valid_on_flavor("flavor", "image")
+    @validation.required_services(consts.Service.NOVA)
+    @validation.required_openstack(users=True)
+    @base.scenario(context={"cleanup": ["nova"]})
+    def pause_and_unpause_server(self, image, flavor,
+                                 force_delete=False, **kwargs):
+        """Create a server, pause, unpause and then delete it
+
+        :param image: image to be used to boot an instance
+        :param flavor: flavor to be used to boot an instance
+        :param force_delete: True if force_delete should be used
+        :param kwargs: Optional additional arguments for server creation
+        """
+        server = self._boot_server(image, flavor, **kwargs)
+        self._pause_server(server)
+        self._unpause_server(server)
+        self._delete_server(server, force=force_delete)
+
+    @types.set(image=types.ImageResourceType,
+               flavor=types.FlavorResourceType)
+    @validation.image_valid_on_flavor("flavor", "image")
+    @validation.required_services(consts.Service.NOVA)
+    @validation.required_openstack(users=True)
+    @base.scenario(context={"cleanup": ["nova"]})
+    def shelve_and_unshelve_server(self, image, flavor,
+                                   force_delete=False, **kwargs):
+        """Create a server, shelve, unshelve and then delete it
+
+        :param image: image to be used to boot an instance
+        :param flavor: flavor to be used to boot an instance
+        :param force_delete: True if force_delete should be used
+        :param kwargs: Optional additional arguments for server creation
+        """
+        server = self._boot_server(image, flavor, **kwargs)
+        self._shelve_server(server)
+        self._unshelve_server(server)
+        self._delete_server(server, force=force_delete)
+
     @types.set(image=types.ImageResourceType,
                flavor=types.FlavorResourceType)
     @validation.image_valid_on_flavor("flavor", "image")
@@ -319,21 +411,29 @@ class NovaServers(utils.NovaScenario,
     @base.scenario(context={"cleanup": ["nova"]})
     def boot_and_live_migrate_server(self, image,
                                      flavor, block_migration=False,
-                                     disk_over_commit=False, **kwargs):
+                                     disk_over_commit=False, min_sleep=0,
+                                     max_sleep=0, **kwargs):
         """Live Migrate a server.
 
         This scenario launches a VM on a compute node available in
         the availability zone and then migrates the VM to another
         compute node on the same availability zone.
 
+        Optional 'min_sleep' and 'max_sleep' parameters allow the scenario
+        to simulate a pause between VM booting and running live migration
+        (of random duration from range [min_sleep, max_sleep]).
+
         :param image: image to be used to boot an instance
         :param flavor: flavor to be used to boot an instance
         :param block_migration: Specifies the migration type
         :param disk_over_commit: Specifies whether to allow overcommit
                                  on migrated instance or not
+        :param min_sleep: Minimum sleep time in seconds (non-negative)
+        :param max_sleep: Maximum sleep time in seconds (non-negative)
         :param kwargs: Optional additional arguments for server creation
         """
         server = self._boot_server(image, flavor, **kwargs)
+        self.sleep_between(min_sleep, max_sleep)
 
         new_host = self._find_host_to_migrate(server)
         self._live_migrate(server, new_host,
@@ -351,7 +451,9 @@ class NovaServers(utils.NovaScenario,
                                                  volume_size,
                                                  block_migration=False,
                                                  disk_over_commit=False,
-                                                 force_delete=False, **kwargs):
+                                                 force_delete=False,
+                                                 min_sleep=0, max_sleep=0,
+                                                 **kwargs):
         """Boot a server from volume and then migrate it.
 
         The scenario first creates a volume and a server booted from
@@ -359,6 +461,10 @@ class NovaServers(utils.NovaScenario,
         then migrates the VM to another compute node on the same availability
         zone.
 
+        Optional 'min_sleep' and 'max_sleep' parameters allow the scenario
+        to simulate a pause between VM booting and running live migration
+        (of random duration from range [min_sleep, max_sleep]).
+
         :param image: image to be used to boot an instance
         :param flavor: flavor to be used to boot an instance
         :param volume_size: volume size (in GB)
@@ -366,6 +472,8 @@ class NovaServers(utils.NovaScenario,
         :param disk_over_commit: Specifies whether to allow overcommit
                                  on migrated instance or not
         :param force_delete: True if force_delete should be used
+        :param min_sleep: Minimum sleep time in seconds (non-negative)
+        :param max_sleep: Maximum sleep time in seconds (non-negative)
         :param kwargs: Optional additional arguments for server creation
         """
         volume = self._create_volume(volume_size, imageRef=image)
@@ -373,6 +481,7 @@ class NovaServers(utils.NovaScenario,
         server = self._boot_server(image, flavor,
                                    block_device_mapping=block_device_mapping,
                                    **kwargs)
+        self.sleep_between(min_sleep, max_sleep)
 
         new_host = self._find_host_to_migrate(server)
         self._live_migrate(server, new_host,
@@ -394,12 +503,18 @@ class NovaServers(utils.NovaScenario,
             block_migration=False,
             disk_over_commit=False,
             boot_server_kwargs=None,
-            create_volume_kwargs=None):
-        """Create a VM, attach a volume to it amd live migrate.
+            create_volume_kwargs=None,
+            min_sleep=0,
+            max_sleep=0):
+        """Create a VM, attach a volume to it and live migrate.
 
         Simple test to create a VM and attach a volume, then migrate the VM,
         detach the volume and delete volume/VM.
 
+        Optional 'min_sleep' and 'max_sleep' parameters allow the scenario
+        to simulate a pause between attaching a volume and running live
+        migration (of random duration from range [min_sleep, max_sleep]).
+
         :param image: Glance image name to use for the VM
         :param flavor: VM flavor name
         :param size: volume size (in GB)
@@ -408,6 +523,8 @@ class NovaServers(utils.NovaScenario,
                                  on migrated instance or not
         :param boot_server_kwargs: optional arguments for VM creation
         :param create_volume_kwargs: optional arguments for volume creation
+        :param min_sleep: Minimum sleep time in seconds (non-negative)
+        :param max_sleep: Maximum sleep time in seconds (non-negative)
         """
 
         if boot_server_kwargs is None:
@@ -415,11 +532,13 @@ class NovaServers(utils.NovaScenario,
         if create_volume_kwargs is None:
             create_volume_kwargs = {}
 
-        server = self._boot_server(image, flavor, boot_server_kwargs)
-        volume = self._create_volume(size, create_volume_kwargs)
+        server = self._boot_server(image, flavor, **boot_server_kwargs)
+        volume = self._create_volume(size, **create_volume_kwargs)
 
         self._attach_volume(server, volume)
 
+        self.sleep_between(min_sleep, max_sleep)
+
         new_host = self._find_host_to_migrate(server)
         self._live_migrate(server, new_host,
                            block_migration, disk_over_commit)
@@ -457,3 +576,45 @@ class NovaServers(utils.NovaScenario,
         else:
             self._resize_revert(server, status="SHUTOFF")
         self._delete_server(server)
+
+    @types.set(from_image=types.ImageResourceType,
+               to_image=types.ImageResourceType,
+               flavor=types.FlavorResourceType)
+    @validation.image_valid_on_flavor("flavor", "from_image")
+    @validation.image_valid_on_flavor("flavor", "to_image")
+    @validation.required_services(consts.Service.NOVA)
+    @validation.required_openstack(admin=True, users=True)
+    @base.scenario(context={"cleanup": ["nova"]})
+    def boot_and_rebuild_server(self, from_image, to_image, flavor, **kwargs):
+        """Rebuild a server.
+
+        This scenario launches a VM, then rebuilds that VM with a
+        different image.
+
+        :param from_image: image to be used to boot an instance
+        :param to_image: image to be used to rebuild the instance
+        :param flavor: flavor to be used to boot an instance
+        :param kwargs: Optional additional arguments for server creation
+        """
+        server = self._boot_server(from_image, flavor, **kwargs)
+        self._rebuild_server(server, to_image)
+        self._delete_server(server)
+
+    @types.set(image=types.ImageResourceType,
+               flavor=types.FlavorResourceType)
+    @validation.image_valid_on_flavor("flavor", "image")
+    @validation.required_services(consts.Service.NOVA)
+    @validation.required_openstack(users=True)
+    @validation.required_contexts("network")
+    @base.scenario(context={"cleanup": ["nova"]})
+    def boot_and_associate_floating_ip(self, image, flavor, **kwargs):
+        """Boot a server and associate a floating IP to it.
+
+        :param image: image to be used to boot an instance
+        :param flavor: flavor to be used to boot an instance
+        :param kwargs: Optional additional arguments for server creation
+        """
+        server = self._boot_server(image, flavor, **kwargs)
+        address = network_wrapper.wrap(self.clients).create_floating_ip(
+            tenant_id=server.tenant_id)
+        self._associate_floating_ip(server, address["ip"])
