@@ -21,6 +21,7 @@ import six
 
 from rally.benchmark.scenarios import base
 from rally.benchmark import utils as bench_utils
+from rally.benchmark.wrappers import network as network_wrapper
 from rally import exceptions
 
 
@@ -32,9 +33,15 @@ option_names_and_defaults = [
     ("boot", 1, 300, 1),
     ("delete", 2, 300, 2),
     ("reboot", 2, 300, 2),
+    ("rebuild", 1, 300, 1),
     ("rescue", 2, 300, 2),
     ("unrescue", 2, 300, 2),
     ("suspend", 2, 300, 2),
+    ("resume", 2, 300, 2),
+    ("pause", 2, 300, 2),
+    ("unpause", 2, 300, 2),
+    ("shelve", 2, 300, 2),
+    ("unshelve", 2, 300, 2),
     ("image_create", 0, 300, 2),
     ("image_delete", 0, 300, 2),
     ("resize", 2, 400, 5),
@@ -63,6 +70,17 @@ for action, prepoll, timeout, poll in option_names_and_defaults:
         )
     ])
 
+NOVA_BENCHMARK_OPTS.extend([
+    cfg.FloatOpt(
+        "nova_detach_volume_timeout",
+        default=float(200),
+        help="Nova volume detach timeout"),
+    cfg.FloatOpt(
+        "nova_detach_volume_poll_interval",
+        default=float(2),
+        help="Nova volume detach poll interval")
+])
+
 CONF = cfg.CONF
 benchmark_group = cfg.OptGroup(name="benchmark",
                                title="benchmark options")
@@ -85,8 +103,8 @@ class NovaScenario(base.Scenario):
 
         Returns when the server is actually booted and in "ACTIVE" state.
 
-        If multiple networks are present, the first network found that
-        isn't associated with a floating IP pool is used.
+        If multiple networks created by Network context are present, the first
+        network found that isn't associated with a floating IP pool is used.
 
         :param image_id: int, image ID for server creation
         :param flavor_id: int, flavor ID for server creation
@@ -160,6 +178,24 @@ class NovaScenario(base.Scenario):
         """
         self._do_server_reboot(server, "HARD")
 
+    @base.atomic_action_timer("nova.rebuild_server")
+    def _rebuild_server(self, server, image, **kwargs):
+        """Rebuild a server with a new image.
+
+        :param server: The server to rebuild.
+        :param image: The new image to rebuild the server with.
+        :param kwargs: Optional additional arguments to pass to the rebuild
+        """
+        server.rebuild(image, **kwargs)
+        time.sleep(CONF.benchmark.nova_server_rebuild_prepoll_delay)
+        bench_utils.wait_for(
+            server,
+            is_ready=bench_utils.resource_is("ACTIVE"),
+            update_resource=bench_utils.get_from_manager(),
+            timeout=CONF.benchmark.nova_server_rebuild_timeout,
+            check_interval=CONF.benchmark.nova_server_rebuild_poll_interval
+        )
+
     @base.atomic_action_timer("nova.start_server")
     def _start_server(self, server):
         """Start the given server.
@@ -247,6 +283,95 @@ class NovaScenario(base.Scenario):
             check_interval=CONF.benchmark.nova_server_suspend_poll_interval
         )
 
+    @base.atomic_action_timer("nova.resume_server")
+    def _resume_server(self, server):
+        """Resumes the suspended server.
+
+        Returns when the server is actually resumed and is in the "ACTIVE"
+        state.
+
+        :param server: Server object
+        """
+        server.resume()
+        time.sleep(CONF.benchmark.nova_server_resume_prepoll_delay)
+        bench_utils.wait_for(
+            server, is_ready=bench_utils.resource_is("ACTIVE"),
+            update_resource=bench_utils.get_from_manager(),
+            timeout=CONF.benchmark.nova_server_resume_timeout,
+            check_interval=CONF.benchmark.nova_server_resume_poll_interval
+        )
+
+    @base.atomic_action_timer("nova.pause_server")
+    def _pause_server(self, server):
+        """Pause the live server.
+
+        Returns when the server is actually paused and is in the "PAUSED"
+        state.
+
+        :param server: Server object
+        """
+        server.pause()
+        time.sleep(CONF.benchmark.nova_server_pause_prepoll_delay)
+        bench_utils.wait_for(
+            server, is_ready=bench_utils.resource_is("PAUSED"),
+            update_resource=bench_utils.get_from_manager(),
+            timeout=CONF.benchmark.nova_server_pause_timeout,
+            check_interval=CONF.benchmark.nova_server_pause_poll_interval
+        )
+
+    @base.atomic_action_timer("nova.unpause_server")
+    def _unpause_server(self, server):
+        """Unpause the paused server.
+
+        Returns when the server is actually unpaused and is in the "ACTIVE"
+        state.
+
+        :param server: Server object
+        """
+        server.unpause()
+        time.sleep(CONF.benchmark.nova_server_unpause_prepoll_delay)
+        bench_utils.wait_for(
+            server, is_ready=bench_utils.resource_is("ACTIVE"),
+            update_resource=bench_utils.get_from_manager(),
+            timeout=CONF.benchmark.nova_server_unpause_timeout,
+            check_interval=CONF.benchmark.nova_server_unpause_poll_interval
+        )
+
+    @base.atomic_action_timer("nova.shelve_server")
+    def _shelve_server(self, server):
+        """Shelve the given server.
+
+        Returns when the server is actually shelved and is in the
+        "SHELVED_OFFLOADED" state.
+
+        :param server: Server object
+        """
+        server.shelve()
+        time.sleep(CONF.benchmark.nova_server_shelve_prepoll_delay)
+        bench_utils.wait_for(
+            server, is_ready=bench_utils.resource_is("SHELVED_OFFLOADED"),
+            update_resource=bench_utils.get_from_manager(),
+            timeout=CONF.benchmark.nova_server_shelve_timeout,
+            check_interval=CONF.benchmark.nova_server_shelve_poll_interval
+        )
+
+    @base.atomic_action_timer("nova.unshelve_server")
+    def _unshelve_server(self, server):
+        """Unshelve the given server.
+
+        Returns when the server is unshelved and is in the "ACTIVE" state.
+
+        :param server: Server object
+        """
+        server.unshelve()
+        time.sleep(CONF.benchmark.nova_server_unshelve_prepoll_delay)
+        bench_utils.wait_for(
+            server, is_ready=bench_utils.resource_is("ACTIVE"),
+            update_resource=bench_utils.get_from_manager(),
+            timeout=CONF.benchmark.nova_server_unshelve_timeout,
+            check_interval=CONF.benchmark.nova_server_unshelve_poll_interval
+        )
+
     def _delete_server(self, server, force=False):
         """Delete the given server.
 
@@ -269,18 +394,6 @@ class NovaScenario(base.Scenario):
                 check_interval=CONF.benchmark.nova_server_delete_poll_interval
             )
 
-    def _delete_all_servers(self, force=False):
-        """Delete all servers in the current tenant.
-
-        :param force: If True, force_delete will be used instead of delete.
-        """
-        atomic_name = ("nova.%sdelete_all_servers") % (force
-                                                       and "force_" or "")
-        with base.AtomicAction(self, atomic_name):
-            servers = self.clients("nova").servers.list()
-            for server in servers:
-                self._delete_server(server, force)
-
     @base.atomic_action_timer("nova.delete_image")
     def _delete_image(self, image):
         """Delete the given image.
@@ -496,9 +609,8 @@ class NovaScenario(base.Scenario):
             volume,
             is_ready=bench_utils.resource_is("available"),
             update_resource=bench_utils.get_from_manager(),
-            timeout=CONF.benchmark.nova_server_resize_revert_timeout,
-            check_interval=(
-                    CONF.benchmark.nova_server_resize_revert_poll_interval)
+            timeout=CONF.benchmark.nova_detach_volume_timeout,
+            check_interval=CONF.benchmark.nova_detach_volume_poll_interval
         )
 
     @base.atomic_action_timer("nova.live_migrate")
@@ -622,3 +734,42 @@ class NovaScenario(base.Scenario):
         """Return security groups list."""
         with base.AtomicAction(self, "nova.list_security_groups"):
             return self.clients("nova").security_groups.list()
+
+    @base.atomic_action_timer("nova.list_floating_ips_bulk")
+    def _list_floating_ips_bulk(self):
+        """List all floating IPs."""
+        return self.admin_clients("nova").floating_ips_bulk.list()
+
+    @base.atomic_action_timer("nova.create_floating_ips_bulk")
+    def _create_floating_ips_bulk(self, ip_range, **kwargs):
+        """Create floating IPs by range."""
+        ip_range = network_wrapper.generate_cidr(start_cidr=ip_range)
+        pool_name = self._generate_random_name(prefix="rally_fip_pool_")
+        return self.admin_clients("nova").floating_ips_bulk.create(
+            ip_range=ip_range, pool=pool_name, **kwargs)
+
+    @base.atomic_action_timer("nova.delete_floating_ips_bulk")
+    def _delete_floating_ips_bulk(self, ip_range):
+        """Delete floating IPs by range."""
+        return self.admin_clients("nova").floating_ips_bulk.delete(ip_range)
+
+    @base.atomic_action_timer("nova.list_hypervisors")
+    def _list_hypervisors(self, detailed=True):
+        """List hypervisors."""
+        return self.admin_clients("nova").hypervisors.list(detailed)
+
+    @base.atomic_action_timer("nova.lock_server")
+    def _lock_server(self, server):
+        """Lock the given server.
+
+        :param server: Server to lock
+        """
+        server.lock()
+
+    @base.atomic_action_timer("nova.unlock_server")
+    def _unlock_server(self, server):
+        """Unlock the given server.
+
+        :param server: Server to unlock
+        """
+        server.unlock()
