@@ -37,7 +37,8 @@ class VMScenario(base.Scenario):
     """
 
     @base.atomic_action_timer("vm.run_command_over_ssh")
-    def _run_command_over_ssh(self, ssh, interpreter, script):
+    def _run_command_over_ssh(self, ssh, interpreter, script,
+                              is_file=True):
         """Run command inside an instance.
 
         This is a separate function so that only script execution is timed.
@@ -46,10 +47,13 @@ class VMScenario(base.Scenario):
         :param interpreter: The interpreter that will be used to execute
                 the script.
         :param script: Path to the script file or its content in a StringIO.
-
+        :param is_file: if True, script represent a path,
+                        else, script contains an inline script.
         :returns: tuple (exit_status, stdout, stderr)
         """
-        if isinstance(script, six.string_types):
+        if not is_file:
+            stdin = script
+        elif isinstance(script, six.string_types):
             stdin = open(script, "rb")
         elif isinstance(script, six.moves.StringIO):
             stdin = script
@@ -60,13 +64,10 @@ class VMScenario(base.Scenario):
 
         return ssh.execute(interpreter, stdin=stdin)
 
-    def _get_netwrap(self):
-        if not hasattr(self, "_netwrap"):
-            self._netwrap = network_wrapper.wrap(self.clients)
-        return self._netwrap
-
-    def _boot_server_with_fip(self, image, flavor, floating_network=None,
+    def _boot_server_with_fip(self, image, flavor,
+                              use_floating_ip=True, floating_network=None,
                               wait_for_ping=True, **kwargs):
+        """Boot server prepared for SSH actions."""
         kwargs["auto_assign_nic"] = True
         server = self._boot_server(image, flavor, **kwargs)
 
@@ -77,19 +78,25 @@ class VMScenario(base.Scenario):
                 "or provide `nics' argument with specific net-id." % {
                     "server": server.name})
 
-        fip = self._attach_floating_ip(server, floating_network)
+        if use_floating_ip:
+            fip = self._attach_floating_ip(server, floating_network)
+        else:
+            internal_network = list(server.networks)[0]
+            fip = {"ip": server.addresses[internal_network][0]["addr"]}
 
         if wait_for_ping:
             self._wait_for_ping(fip["ip"])
 
-        return server, fip
+        return server, {"ip": fip.get("ip"),
+                        "id": fip.get("id"),
+                        "is_floating": use_floating_ip}
 
     @base.atomic_action_timer("vm.attach_floating_ip")
     def _attach_floating_ip(self, server, floating_network):
         internal_network = list(server.networks)[0]
         fixed_ip = server.addresses[internal_network][0]["addr"]
 
-        fip = self._get_netwrap().create_floating_ip(
+        fip = network_wrapper.wrap(self.clients).create_floating_ip(
             ext_network=floating_network, int_network=internal_network,
             tenant_id=server.tenant_id, fixed_ip=fixed_ip)
 
@@ -103,11 +110,12 @@ class VMScenario(base.Scenario):
                 LOG, _("Unable to delete IP: %s") % fip["ip"]):
             if self.check_ip_address(fip["ip"])(server):
                 self._dissociate_floating_ip(server, fip["ip"])
-            self._get_netwrap().delete_floating_ip(fip["id"], wait=True)
+            network_wrapper.wrap(self.clients).delete_floating_ip(fip["id"],
+                                                                  wait=True)
 
     def _delete_server_with_fip(self, server, fip, force_delete=False):
-        self._delete_floating_ip(server, fip)
-
+        if fip["is_floating"]:
+            self._delete_floating_ip(server, fip)
         return self._delete_server(server, force=force_delete)
 
     @base.atomic_action_timer("vm.wait_for_ssh")
@@ -122,20 +130,30 @@ class VMScenario(base.Scenario):
             timeout=120
         )
 
-    def _run_command(self, server_ip, port, username, password,
-                     interpreter, script, pkey=None):
+    def _run_command(self, server_ip, port, username, password, interpreter,
+                     script, pkey=None, is_file=True):
         """Run command via SSH on server.
 
         Create SSH connection for server, wait for server to become
         available (there is a delay between server being set to ACTIVE
         and sshd being available). Then call run_command_over_ssh to actually
         execute the command.
+        :param server_ip: server ip address
+        :param port: ssh port for SSH connection
+        :param username: str. ssh username for server
+        :param password: Password for SSH authentication
+        :param interpreter: server's interpreter to execute the script
+        :param script: script to run on server
+        :param pkey: key for SSH authentication
+        :param is_file: if True, script represent a path,
+                        else, script contains an inline script.
         """
         pkey = pkey if pkey else self.context["user"]["keypair"]["private"]
         ssh = sshutils.SSH(username, server_ip, port=port,
                            pkey=pkey, password=password)
         self._wait_for_ssh(ssh)
-        return self._run_command_over_ssh(ssh, interpreter, script)
+        return self._run_command_over_ssh(ssh, interpreter,
+                                          script, is_file)
 
     @staticmethod
     def _ping_ip_address(host, should_succeed=True):
