@@ -20,12 +20,15 @@ import re
 
 from glanceclient import exc as glance_exc
 from novaclient import exceptions as nova_exc
+import six
 
 from rally.benchmark.context import flavors as flavors_ctx
 from rally.benchmark import types as types
 from rally.common.i18n import _
 from rally import consts
 from rally import exceptions
+from rally import objects
+from rally import osclients
 from rally.verification.tempest import tempest
 
 
@@ -126,8 +129,22 @@ def number(config, clients, deployment, param_name, minval=None, maxval=None,
             % {"name": param_name, "val": val, "type": num_func.__name__})
 
 
+def _file_access_ok(file_name, mode, param_name, required=True):
+    if not file_name:
+        return ValidationResult(
+            not required,
+            "Parameter %(param_name)s required" % {"param_name": param_name})
+    if not os.access(file_name, mode):
+        return ValidationResult(
+            False, "Could not open %(file_name)s with mode %(mode)s "
+            "for parameter %(param_name)s"
+            % {"file_name": file_name, "mode": mode, "param_name": param_name})
+    return ValidationResult(True)
+
+
 @validator
-def file_exists(config, clients, deployment, param_name, mode=os.R_OK):
+def file_exists(config, clients, deployment, param_name, mode=os.R_OK,
+                required=True):
     """Validator checks parameter is proper path to file with proper mode.
 
     Ensure a file exists and can be accessed with the specified mode.
@@ -139,16 +156,13 @@ def file_exists(config, clients, deployment, param_name, mode=os.R_OK):
         * os.W_OK (file is writable)
         * os.X_OK (file is executable)
 
-        If multiple modes are rquired they can be added, eg:
+        If multiple modes are required they can be added, eg:
             mode=os.R_OK+os.W_OK
+    :param required: Boolean indicating whether this argument is required.
     """
 
-    file_name = config.get("args", {}).get(param_name)
-    if not os.access(file_name, mode):
-        return ValidationResult(
-            False, "Could not open %(file_name)s with mode %(mode)s "
-            "for parameter %(param_name)s"
-            % {"file_name": file_name, "mode": mode, "param_name": param_name})
+    return _file_access_ok(config.get("args", {}).get(param_name), mode,
+                           param_name, required)
 
 
 def _get_validated_image(config, clients, param_name):
@@ -393,6 +407,28 @@ def required_services(config, clients, deployment, *required_services):
                 False, _("Service is not available: %s") % service)
 
 
+@validator
+def required_cinder_services(config, clients, deployment, service_name):
+    """Validator checks that specified Cinder service is available.
+
+    It uses Cinder client with admin permissions to call 'cinder service-list'
+    call
+
+    :param service_name: Cinder service name
+    """
+
+    admin_client = osclients.Clients(
+        objects.Endpoint(**deployment["admin"])).cinder()
+
+    for service in admin_client.services.list():
+        if (service.binary == six.text_type(service_name) and
+                service.state == six.text_type("up")):
+            return ValidationResult(True)
+
+    msg = _("%s service is not available") % service_name
+    return ValidationResult(False, msg)
+
+
 @validator
 def required_clients(config, clients, task, *components):
     """Validator checks if specified OpenStack clients are available.
@@ -412,7 +448,7 @@ def required_clients(config, clients, task, *components):
 
 @validator
 def required_contexts(config, clients, deployment, *context_names):
-    """Validator hecks if required benchmark contexts are specified.
+    """Validator checks if required benchmark contexts are specified.
 
     :param *context_names: list of context names that should be specified
     """
@@ -469,3 +505,11 @@ def volume_type_exists(config, clients, deployment, param_name):
             message = (_("Must have at least one volume type created "
                          "when specifying use of volume types."))
             return ValidationResult(False, message)
+
+
+@validator
+def restricted_parameters(config, clients, deployment, param_name):
+    """Validator that check that parameter is not set."""
+    if param_name in config.get("args", {}):
+        return ValidationResult(False, "You can't specify parameter `%s`" %
+                                param_name)
