@@ -21,6 +21,7 @@ import os
 import sys
 import warnings
 
+import decorator
 import jsonschema
 from oslo_config import cfg
 from oslo_utils import encodeutils
@@ -84,7 +85,9 @@ def validate_args(fn, *args, **kwargs):
 
 
 def print_list(objs, fields, formatters=None, sortby_index=0,
-               mixed_case_fields=None, field_labels=None):
+               mixed_case_fields=None, field_labels=None,
+               table_label=None, print_header=True, print_border=True,
+               out=sys.stdout):
     """Print a list or objects as a table, one row per object.
 
     :param objs: iterable of :class:`Resource`
@@ -95,6 +98,10 @@ def print_list(objs, fields, formatters=None, sortby_index=0,
         have mixed case names (e.g., 'serverId')
     :param field_labels: Labels to use in the heading of the table, default to
         fields.
+    :param table_label: Label to use as header for the whole table.
+    :param print_header: print table header.
+    :param print_border: print table border.
+    :param out: stream to write output to.
     """
     formatters = formatters or {}
     mixed_case_fields = mixed_case_fields or []
@@ -125,10 +132,69 @@ def print_list(objs, fields, formatters=None, sortby_index=0,
                 row.append(data)
         pt.add_row(row)
 
+    if not print_border or not print_header:
+        pt.set_style(prettytable.PLAIN_COLUMNS)
+        pt.left_padding_width = 0
+        pt.right_padding_width = 1
+
+    table_body = pt.get_string(header=print_header,
+                               border=print_border,
+                               **kwargs) + "\n"
+
+    table_header = ""
+
+    if table_label:
+        table_width = table_body.index("\n")
+        table_header = make_table_header(table_label, table_width)
+        table_header += "\n"
+
     if six.PY3:
-        print(encodeutils.safe_encode(pt.get_string(**kwargs)).decode())
+        if table_header:
+            out.write(encodeutils.safe_encode(table_header).decode())
+        out.write(encodeutils.safe_encode(table_body).decode())
     else:
-        print(encodeutils.safe_encode(pt.get_string(**kwargs)))
+        if table_header:
+            out.write(encodeutils.safe_encode(table_header))
+        out.write(encodeutils.safe_encode(table_body))
+
+
+def make_table_header(table_label, table_width,
+                      junction_char="+", horizontal_char="-",
+                      vertical_char="|"):
+    """Generalized way make a table header string.
+
+    :param table_label: label to print on header
+    :param table_width: total width of table
+    :param junction_char: character used where vertical and
+        horizontal lines meet.
+    :param horizontal_char: character used for horizontal lines.
+    :param vertical_char: character used for vertical lines.
+
+    :returns string
+    """
+
+    if len(table_label) >= (table_width - 2):
+        raise ValueError(_("Table header %s is longer than total"
+                           "width of the table."))
+
+    label_and_space_width = table_width - len(table_label) - 2
+    padding = 0 if label_and_space_width % 2 == 0 else 1
+
+    half_table_width = label_and_space_width // 2
+    left_spacing = (" " * half_table_width)
+    right_spacing = (" " * (half_table_width + padding))
+
+    border_line = "".join((junction_char,
+                           (horizontal_char * (table_width - 2)),
+                           junction_char,))
+
+    label_line = "".join((vertical_char,
+                          left_spacing,
+                          table_label,
+                          right_spacing,
+                          vertical_char,))
+
+    return "\n".join((border_line, label_line,))
 
 
 def make_header(text, size=80, symbol="-"):
@@ -149,6 +215,23 @@ def suppress_warnings(f):
     return f
 
 
+@decorator.decorator
+def process_keystone_exc(f, *args, **kwargs):
+    from keystoneclient import exceptions as keystone_exc
+
+    try:
+        return f(*args, **kwargs)
+    except keystone_exc.Unauthorized as e:
+        print(_("User credentials are wrong! \n%s") % e)
+        return 1
+    except keystone_exc.AuthorizationFailure as e:
+        print(_("Failed to authorize! \n%s") % e)
+        return 1
+    except keystone_exc.ConnectionRefused as e:
+        print(_("Rally can't reach the Keystone service! \n%s") % e)
+        return 1
+
+
 class CategoryParser(argparse.ArgumentParser):
 
     """Customized arguments parser
@@ -215,6 +298,17 @@ def args(*args, **kwargs):
     return _decorator
 
 
+def alias(command_name):
+    """Allow cli to use alias command name instead of function name.
+
+    :param command_name: desired command name
+    """
+    def decorator(func):
+        func.alias = command_name
+        return func
+    return decorator
+
+
 def deprecated_args(*args, **kwargs):
     def _decorator(func):
         func.__dict__.setdefault("args", []).insert(0, (args, kwargs))
@@ -254,7 +348,7 @@ def _compose_category_description(category):
         sublen = lambda item: len(item[0])
         first_column_len = max(map(sublen, descr_pairs)) + MARGIN
         for item in descr_pairs:
-            name = item[0]
+            name = getattr(item[1], "alias", item[0])
             if item[1].__doc__:
                 doc = utils.parse_docstring(
                     item[1].__doc__)["short_description"]
@@ -300,15 +394,15 @@ def _add_command_parsers(categories, subparsers):
 
         category_subparsers = parser.add_subparsers(dest="action")
 
-        for action, action_fn in _methods_of(command_object):
-            descr = _compose_action_description(action_fn)
+        for method_name, method in _methods_of(command_object):
+            descr = _compose_action_description(method)
             parser = category_subparsers.add_parser(
-                action,
+                getattr(method, "alias", method_name),
                 formatter_class=argparse.RawDescriptionHelpFormatter,
                 description=descr, help=descr)
 
             action_kwargs = []
-            for args, kwargs in getattr(action_fn, "args", []):
+            for args, kwargs in getattr(method, "args", []):
                 # FIXME(markmc): hack to assume dest is the arg name without
                 # the leading hyphens if no dest is supplied
                 kwargs.setdefault("dest", args[0][2:])
@@ -316,7 +410,7 @@ def _add_command_parsers(categories, subparsers):
                 kwargs["dest"] = "action_kwarg_" + kwargs["dest"]
                 parser.add_argument(*args, **kwargs)
 
-            parser.set_defaults(action_fn=action_fn)
+            parser.set_defaults(action_fn=method)
             parser.set_defaults(action_kwargs=action_kwargs)
             parser.add_argument("action_args", nargs="*")
 
@@ -357,6 +451,11 @@ def run(argv, categories):
             urllib3_log = logging.getLogger("urllib3").logger
             urllib3_log.setLevel(logging.WARNING)
 
+            # NOTE(wtakase): This is for suppressing boto error logging.
+            LOG.debug("ERROR log from boto module is hide.")
+            boto_log = logging.getLogger("boto").logger
+            boto_log.setLevel(logging.CRITICAL)
+
     except cfg.ConfigFilesNotFoundError:
         cfgfile = CONF.config_file[-1] if CONF.config_file else None
         if cfgfile and not os.access(cfgfile, os.R_OK):
@@ -411,6 +510,7 @@ def run(argv, categories):
     try:
         utils.load_plugins("/opt/rally/plugins/")
         utils.load_plugins(os.path.expanduser("~/.rally/plugins/"))
+        utils.import_modules_from_package("rally.plugins")
 
         validate_deprecated_args(argv, fn)
 
@@ -480,6 +580,7 @@ complete -F _rally rally
     completion = []
     for category, cmds in main.categories.items():
         for name, command in _methods_of(cmds):
+            command_name = getattr(command, "alias", name)
             args_list = []
             for arg in getattr(command, "args", []):
                 if getattr(command, "deprecated_args", []):
@@ -490,5 +591,5 @@ complete -F _rally rally
             args = " ".join(args_list)
 
             completion.append("""    OPTS["{cat}_{cmd}"]="{args}"\n""".format(
-                    cat=category, cmd=name, args=args))
+                    cat=category, cmd=command_name, args=args))
     return bash_data % {"data": "".join(sorted(completion))}
