@@ -18,7 +18,6 @@
 from __future__ import print_function
 import json
 import os
-import pprint
 import sys
 import webbrowser
 
@@ -215,11 +214,11 @@ class TaskCommands(object):
             print("Benchmarking... This can take a while...\n")
             print("To track task status use:\n")
             print("\trally task status\n\tor\n\trally task detailed\n")
+            if do_use:
+                self.use(task["uuid"])
             api.Task.start(deployment, input_task, task=task,
                            abort_on_sla_failure=abort_on_sla_failure)
             self.detailed(task_id=task["uuid"])
-            if do_use:
-                self.use(task["uuid"])
         except exceptions.InvalidConfigException:
             return(1)
 
@@ -286,6 +285,7 @@ class TaskCommands(object):
                 if r["atomic_actions"]:
                     for action in atomic_actions:
                         dlist.append(r["atomic_actions"].get(action) or 0)
+                table_rows.append(rutils.Struct(**dict(zip(headers, dlist))))
             cliutils.print_list(table_rows,
                                 fields=headers,
                                 formatters=formatters)
@@ -323,14 +323,15 @@ class TaskCommands(object):
             print("test scenario %s" % key["name"])
             print("args position %s" % key["pos"])
             print("args values:")
-            pprint.pprint(key["kw"])
+            print(json.dumps(key["kw"], indent=2))
 
             raw = result["data"]["raw"]
-            table_cols = ["action", "min (sec)", "avg (sec)", "max (sec)",
-                          "90 percentile", "95 percentile", "success",
-                          "count"]
-            float_cols = ["min (sec)", "avg (sec)", "max (sec)",
-                          "90 percentile", "95 percentile"]
+            table_cols = ["action", "min", "median",
+                          "90%ile", "95%ile", "max",
+                          "avg", "success", "count"]
+            float_cols = ["min", "median",
+                          "90%ile", "95%ile", "max",
+                          "avg"]
             formatters = dict(zip(float_cols,
                                   [cliutils.pretty_float_formatter(col, 3)
                                    for col in float_cols]))
@@ -341,20 +342,22 @@ class TaskCommands(object):
                 durations = actions_data[action]
                 if durations:
                     data = [action,
-                            min(durations),
-                            utils.mean(durations),
-                            max(durations),
-                            utils.percentile(durations, 0.90),
-                            utils.percentile(durations, 0.95),
+                            round(min(durations), 3),
+                            round(utils.median(durations), 3),
+                            round(utils.percentile(durations, 0.90), 3),
+                            round(utils.percentile(durations, 0.95), 3),
+                            round(max(durations), 3),
+                            round(utils.mean(durations), 3),
                             "%.1f%%" % (len(durations) * 100.0 / len(raw)),
                             len(raw)]
                 else:
-                    data = [action, None, None, None, None, None,
+                    data = [action, None, None, None, None, None, None,
                             "0.0%", len(raw)]
                 table_rows.append(rutils.Struct(**dict(zip(table_cols, data))))
 
             cliutils.print_list(table_rows, fields=table_cols,
-                                formatters=formatters)
+                                formatters=formatters,
+                                table_label="Response Times (sec)")
 
             if iterations_data:
                 _print_iterations_data(raw)
@@ -372,10 +375,11 @@ class TaskCommands(object):
                 keys = set()
                 for ssr in ssrs:
                     keys.update(ssr.keys())
-                headers = ["key", "max", "avg", "min",
-                           "90 pecentile", "95 pecentile"]
-                float_cols = ["max", "avg", "min",
-                              "90 pecentile", "95 pecentile"]
+                headers = ["key", "min", "median",
+                           "90%ile", "95%ile", "max",
+                           "avg"]
+                float_cols = ["min", "median", "90%ile",
+                              "95%ile", "max", "avg"]
                 formatters = dict(zip(float_cols,
                                   [cliutils.pretty_float_formatter(col, 3)
                                    for col in float_cols]))
@@ -385,18 +389,20 @@ class TaskCommands(object):
 
                     if values:
                         row = [str(key),
-                               max(values),
-                               utils.mean(values),
-                               min(values),
-                               utils.percentile(values, 0.90),
-                               utils.percentile(values, 0.95)]
+                               round(min(values), 3),
+                               round(utils.median(values), 3),
+                               round(utils.percentile(values, 0.90), 3),
+                               round(utils.percentile(values, 0.95), 3),
+                               round(max(values), 3),
+                               round(utils.mean(values), 3)]
                     else:
-                        row = [str(key)] + ["n/a"] * 5
+                        row = [str(key)] + ["n/a"] * 6
                     table_rows.append(rutils.Struct(**dict(zip(headers, row))))
                 print("\nScenario Specific Results\n")
                 cliutils.print_list(table_rows,
                                     fields=headers,
-                                    formatters=formatters)
+                                    formatters=formatters,
+                                    table_label="Response Times (sec)")
 
                 for result in raw:
                     errors = result["scenario_output"].get("errors")
@@ -421,7 +427,6 @@ class TaskCommands(object):
 
         :param task_id: Task uuid
         """
-
         results = [{"key": x["key"], "result": x["data"]["raw"],
                     "sla": x["data"]["sla"],
                     "load_duration": x["data"]["load_duration"],
@@ -431,7 +436,8 @@ class TaskCommands(object):
         if results:
             print(json.dumps(results, sort_keys=True, indent=4))
         else:
-            print(_("The task %s can not be found") % task_id)
+            print(_("The task %s is still running, results will become "
+                    "available when it is finished.") % task_id)
             return(1)
 
     @cliutils.args("--deployment", type=str, dest="deployment",
@@ -443,8 +449,11 @@ class TaskCommands(object):
     @cliutils.args("--status", type=str, dest="status",
                    help="List tasks with specified status."
                    " Available statuses: %s" % ", ".join(consts.TaskStatus))
+    @cliutils.args("--uuids-only", action="store_true",
+                   dest="uuids_only", help="List task UUIDs only")
     @envutils.with_default_deployment(cli_arg_name="deployment")
-    def list(self, deployment=None, all_deployments=False, status=None):
+    def list(self, deployment=None, all_deployments=False, status=None,
+             uuids_only=False):
         """List tasks, started and finished.
 
         Displayed tasks could be filtered by status or deployment.
@@ -454,6 +463,7 @@ class TaskCommands(object):
         :param status: task status to filter by.
             Available task statuses are in rally.consts.TaskStatus
         :param all_deployments: display tasks from all deployments
+        :param uuids_only: list task UUIDs only
         """
 
         filters = {}
@@ -477,7 +487,12 @@ class TaskCommands(object):
         for x in task_list:
             x["duration"] = x["updated_at"] - x["created_at"]
 
-        if task_list:
+        if uuids_only:
+            if task_list:
+                cliutils.print_list(task_list, ["uuid"],
+                                    print_header=False,
+                                    print_border=False)
+        elif task_list:
             cliutils.print_list(
                 task_list,
                 headers, sortby_index=headers.index("created_at"))
@@ -512,8 +527,8 @@ class TaskCommands(object):
 
         tasks = isinstance(tasks, list) and tasks or [tasks]
 
-        results = list()
-        processed_names = dict()
+        results = []
+        processed_names = {}
         for task_file_or_uuid in tasks:
             if os.path.exists(os.path.expanduser(task_file_or_uuid)):
                 with open(os.path.expanduser(task_file_or_uuid),
