@@ -41,7 +41,7 @@ class RallyException(Exception):
     with the keyword arguments provided to the constructor.
 
     """
-    msg_fmt = _("An unknown exception occurred.")
+    msg_fmt = _("%(message)s")
 
     def __init__(self, message=None, **kwargs):
         self.kwargs = kwargs
@@ -168,6 +168,10 @@ class DeploymentIsBusy(RallyException):
                 "uuid=%(uuid)s.")
 
 
+class RallyAssertionError(RallyException):
+    msg_fmt = _("Assertion error: %(message)s")
+
+
 class ResourceNotFound(NotFoundException):
     msg_fmt = _("Resource with id=%(id)s not found.")
 
@@ -191,7 +195,7 @@ class GetResourceErrorStatus(GetResourceFailure):
 
 
 class ScriptError(RallyException):
-    msg_fmt = _("Script execution failed.")
+    msg_fmt = _("Script execution failed: %(message)s")
 
 
 class TaskInvalidStatus(RallyException):
@@ -250,7 +254,7 @@ class ImageCleanUpException(CleanUpException):
 
 class IncompatiblePythonVersion(RallyException):
     msg_fmt = _("Incompatible python version found '%(version)s', "
-                "required at least python>=2.7.x")
+                "required '%(required_version)s'")
 
 
 class WorkerNotFound(NotFoundException):
