@@ -15,24 +15,9 @@
 
 import os
 
-from ceilometerclient import client as ceilometer
-from cinderclient import client as cinder
-from designateclient import v1 as designate
-import glanceclient as glance
-from heatclient import client as heat
-from ironicclient import client as ironic
-from keystoneclient import discover as keystone_discover
-from keystoneclient import exceptions as keystone_exceptions
-from keystoneclient.v2_0 import client as keystone_v2
-from keystoneclient.v3 import client as keystone_v3
-from neutronclient.neutron import client as neutron
-from novaclient import client as nova
 from oslo_config import cfg
-from saharaclient import client as sahara
-from swiftclient import client as swift
-from troveclient import client as trove
-from zaqarclient.queues import client as zaqar
 
+from rally.common.i18n import _
 from rally.common import log as logging
 from rally import consts
 from rally import exceptions
@@ -45,17 +30,15 @@ OSCLIENTS_OPTS = [
     cfg.FloatOpt("openstack_client_http_timeout", default=180.0,
                  help="HTTP timeout for any of OpenStack service in seconds"),
     cfg.BoolOpt("https_insecure", default=False,
-                help="Use SSL for all OpenStack API interfaces"),
+                help="Use SSL for all OpenStack API interfaces",
+                deprecated_for_removal=True),
     cfg.StrOpt("https_cacert", default=None,
-               help="Path to CA server cetrificate for SSL")
+               help="Path to CA server cetrificate for SSL",
+               deprecated_for_removal=True)
 ]
 CONF.register_opts(OSCLIENTS_OPTS)
 
 
-# NOTE(boris-42): super dirty hack to fix nova python client 2.17 thread safe
-nova._adapter_pool = lambda x: nova.adapters.HTTPAdapter()
-
-
 def cached(func):
     """Cache client handles."""
 
@@ -73,12 +56,15 @@ def cached(func):
 
 
 def create_keystone_client(args):
+    from keystoneclient import discover as keystone_discover
     discover = keystone_discover.Discover(**args)
     for version_data in discover.version_data():
         version = version_data["version"]
         if version[0] <= 2:
+            from keystoneclient.v2_0 import client as keystone_v2
             return keystone_v2.Client(**args)
         elif version[0] == 3:
+            from keystoneclient.v3 import client as keystone_v3
             return keystone_v3.Client(**args)
     raise exceptions.RallyException(
         "Failed to discover keystone version for url %(auth_url)s.", **args)
@@ -89,6 +75,12 @@ class Clients(object):
 
     def __init__(self, endpoint):
         self.endpoint = endpoint
+        # NOTE(kun) Apply insecure/cacert settings from rally.conf if those are
+        # not set in deployment config. Remove it when invaild.
+        if self.endpoint.insecure is None:
+            self.endpoint.insecure = CONF.https_insecure
+        if self.endpoint.cacert is None:
+            self.endpoint.cacert = CONF.https_cacert
         self.cache = {}
 
     @classmethod
@@ -111,7 +103,7 @@ class Clients(object):
         """Return keystone client."""
         new_kw = {
             "timeout": CONF.openstack_client_http_timeout,
-            "insecure": CONF.https_insecure, "cacert": CONF.https_cacert
+            "insecure": self.endpoint.insecure, "cacert": self.endpoint.cacert
         }
         kw = self.endpoint.to_dict()
         kw.update(new_kw)
@@ -125,6 +117,7 @@ class Clients(object):
 
         :returns: Keystone Client
         """
+        from keystoneclient import exceptions as keystone_exceptions
         try:
             # Ensure that user is admin
             client = self.keystone()
@@ -139,9 +132,24 @@ class Clients(object):
                 url=self.endpoint.auth_url)
         return client
 
+    def _get_auth_info(self, user_key="username",
+                       password_key="password",
+                       auth_url_key="auth_url",
+                       project_name_key="project_id"
+                       ):
+        kw = {
+            user_key: self.endpoint.username,
+            password_key: self.endpoint.password,
+            auth_url_key: self.endpoint.auth_url
+        }
+        if project_name_key:
+            kw.update({project_name_key: self.endpoint.tenant_name})
+        return kw
+
     @cached
     def nova(self, version="2"):
         """Return nova client."""
+        from novaclient import client as nova
         kc = self.keystone()
         compute_api_url = kc.service_catalog.url_for(
             service_type="compute",
@@ -151,14 +159,16 @@ class Clients(object):
                              auth_token=kc.auth_token,
                              http_log_debug=logging.is_debug(),
                              timeout=CONF.openstack_client_http_timeout,
-                             insecure=CONF.https_insecure,
-                             cacert=CONF.https_cacert)
+                             insecure=self.endpoint.insecure,
+                             cacert=self.endpoint.cacert,
+                             **self._get_auth_info(password_key="api_key"))
         client.set_management_url(compute_api_url)
         return client
 
     @cached
     def neutron(self, version="2.0"):
         """Return neutron client."""
+        from neutronclient.neutron import client as neutron
         kc = self.keystone()
         network_api_url = kc.service_catalog.url_for(
             service_type="network",
@@ -168,13 +178,17 @@ class Clients(object):
                                 token=kc.auth_token,
                                 endpoint_url=network_api_url,
                                 timeout=CONF.openstack_client_http_timeout,
-                                insecure=CONF.https_insecure,
-                                ca_cert=CONF.https_cacert)
+                                insecure=self.endpoint.insecure,
+                                ca_cert=self.endpoint.cacert,
+                                **self._get_auth_info(
+                                    project_name_key="tenant_name")
+                                )
         return client
 
     @cached
     def glance(self, version="1"):
         """Return glance client."""
+        import glanceclient as glance
         kc = self.keystone()
         image_api_url = kc.service_catalog.url_for(
             service_type="image",
@@ -184,13 +198,14 @@ class Clients(object):
                                endpoint=image_api_url,
                                token=kc.auth_token,
                                timeout=CONF.openstack_client_http_timeout,
-                               insecure=CONF.https_insecure,
-                               cacert=CONF.https_cacert)
+                               insecure=self.endpoint.insecure,
+                               cacert=self.endpoint.cacert)
         return client
 
     @cached
     def heat(self, version="1"):
         """Return heat client."""
+        from heatclient import client as heat
         kc = self.keystone()
         orchestration_api_url = kc.service_catalog.url_for(
             service_type="orchestration",
@@ -200,18 +215,21 @@ class Clients(object):
                              endpoint=orchestration_api_url,
                              token=kc.auth_token,
                              timeout=CONF.openstack_client_http_timeout,
-                             insecure=CONF.https_insecure,
-                             cacert=CONF.https_cacert)
+                             insecure=self.endpoint.insecure,
+                             cacert=self.endpoint.cacert,
+                             **self._get_auth_info(project_name_key=None))
         return client
 
     @cached
     def cinder(self, version="1"):
         """Return cinder client."""
-        client = cinder.Client(version, None, None,
+        from cinderclient import client as cinder
+        client = cinder.Client(version,
                                http_log_debug=logging.is_debug(),
                                timeout=CONF.openstack_client_http_timeout,
-                               insecure=CONF.https_insecure,
-                               cacert=CONF.https_cacert)
+                               insecure=self.endpoint.insecure,
+                               cacert=self.endpoint.cacert,
+                               **self._get_auth_info(password_key="api_key"))
         kc = self.keystone()
         volume_api_url = kc.service_catalog.url_for(
             service_type="volume",
@@ -224,6 +242,7 @@ class Clients(object):
     @cached
     def ceilometer(self, version="2"):
         """Return ceilometer client."""
+        from ceilometerclient import client as ceilometer
         kc = self.keystone()
         metering_api_url = kc.service_catalog.url_for(
             service_type="metering",
@@ -239,13 +258,15 @@ class Clients(object):
                     os_endpoint=metering_api_url,
                     token=auth_token,
                     timeout=CONF.openstack_client_http_timeout,
-                    insecure=CONF.https_insecure,
-                    cacert=CONF.https_cacert)
+                    insecure=self.endpoint.insecure,
+                    cacert=self.endpoint.cacert,
+                    **self._get_auth_info(project_name_key="tenant_name"))
         return client
 
     @cached
     def ironic(self, version="1.0"):
         """Return Ironic client."""
+        from ironicclient import client as ironic
         kc = self.keystone()
         baremetal_api_url = kc.service_catalog.url_for(
             service_type="baremetal",
@@ -255,24 +276,25 @@ class Clients(object):
                                    os_auth_token=kc.auth_token,
                                    ironic_url=baremetal_api_url,
                                    timeout=CONF.openstack_client_http_timeout,
-                                   insecure=CONF.https_insecure,
-                                   cacert=CONF.https_cacert)
+                                   insecure=self.endpoint.insecure,
+                                   cacert=self.endpoint.cacert)
         return client
 
     @cached
     def sahara(self, version="1.1"):
         """Return Sahara client."""
+        from saharaclient import client as sahara
         client = sahara.Client(version,
-                               username=self.endpoint.username,
-                               api_key=self.endpoint.password,
-                               project_name=self.endpoint.tenant_name,
-                               auth_url=self.endpoint.auth_url)
+                               **self._get_auth_info(
+                                   password_key="api_key",
+                                   project_name_key="project_name"))
 
         return client
 
     @cached
     def zaqar(self, version=1.1):
         """Return Zaqar client."""
+        from zaqarclient.queues import client as zaqar
         kc = self.keystone()
         messaging_api_url = kc.service_catalog.url_for(
             service_type="messaging",
@@ -284,7 +306,7 @@ class Clients(object):
             "os_project_name": self.endpoint.tenant_name,
             "os_project_id": kc.auth_tenant_id,
             "os_auth_url": self.endpoint.auth_url,
-            "insecure": CONF.https_insecure,
+            "insecure": self.endpoint.insecure,
         }}}
         client = zaqar.Client(url=messaging_api_url,
                               version=version,
@@ -310,6 +332,7 @@ class Clients(object):
     @cached
     def designate(self):
         """Return designate client."""
+        from designateclient import v1 as designate
         kc = self.keystone()
         dns_api_url = kc.service_catalog.url_for(
             service_type="dns",
@@ -318,21 +341,20 @@ class Clients(object):
         client = designate.Client(
             endpoint=dns_api_url,
             token=kc.auth_token,
-            insecure=CONF.https_insecure)
+            insecure=self.endpoint.insecure)
         return client
 
     @cached
     def trove(self, version="1.0"):
         """Returns trove client."""
+        from troveclient import client as trove
         client = trove.Client(version,
-                              username=self.endpoint.username,
-                              api_key=self.endpoint.password,
-                              project_id=self.endpoint.tenant_name,
-                              auth_url=self.endpoint.auth_url,
                               region_name=self.endpoint.region_name,
                               timeout=CONF.openstack_client_http_timeout,
-                              insecure=CONF.https_insecure,
-                              cacert=CONF.https_cacert)
+                              insecure=self.endpoint.insecure,
+                              cacert=self.endpoint.cacert,
+                              **self._get_auth_info(password_key="api_key")
+                              )
         return client
 
     @cached
@@ -354,6 +376,7 @@ class Clients(object):
     @cached
     def swift(self):
         """Return swift client."""
+        from swiftclient import client as swift
         kc = self.keystone()
         object_api_url = kc.service_catalog.url_for(
             service_type="object-store",
@@ -362,8 +385,36 @@ class Clients(object):
         client = swift.Connection(retries=1,
                                   preauthurl=object_api_url,
                                   preauthtoken=kc.auth_token,
-                                  insecure=CONF.https_insecure,
-                                  cacert=CONF.https_cacert)
+                                  insecure=self.endpoint.insecure,
+                                  cacert=self.endpoint.cacert,
+                                  **self._get_auth_info(
+                                      user_key="user",
+                                      password_key="key",
+                                      auth_url_key="authurl",
+                                      project_name_key="tenant_name")
+                                  )
+        return client
+
+    @cached
+    def ec2(self):
+        """Return ec2 client."""
+        import boto
+        kc = self.keystone()
+        if kc.version != "v2.0":
+            raise exceptions.RallyException(
+                _("Rally EC2 benchmark currently supports only"
+                  "Keystone version 2"))
+        ec2_credential = kc.ec2.create(user_id=kc.auth_user_id,
+                                       tenant_id=kc.auth_tenant_id)
+        ec2_api_url = kc.service_catalog.url_for(
+            service_type=consts.ServiceType.EC2,
+            endpoint_type=self.endpoint.endpoint_type,
+            region_name=self.endpoint.region_name)
+        client = boto.connect_ec2_endpoint(
+            url=ec2_api_url,
+            aws_access_key_id=ec2_credential.access,
+            aws_secret_access_key=ec2_credential.secret,
+            is_secure=self.endpoint.insecure)
         return client
 
     @cached
@@ -378,3 +429,34 @@ class Clients(object):
             if service_type in consts.ServiceType:
                 services_data[service_type] = consts.ServiceType[service_type]
         return services_data
+
+    @classmethod
+    def register(cls, client_name):
+        """Decorator that adds new OpenStack client dynamically.
+
+        :param client_name: str name how client will be named in Rally clients
+
+        Decorated function will be added to Clients in runtime, so its sole
+        argument is a Clients instance.
+
+        Example:
+          >>> from rally import osclients
+          >>> @osclients.Clients.register("supernova")
+          ... def another_nova_client(self):
+          ...   from novaclient import client as nova
+          ...   return nova.Client("2", auth_token=self.keystone().auth_token,
+          ...                      **self._get_auth_info(password_key="key"))
+          ...
+          >>> clients = osclients.Clients.create_from_env()
+          >>> clients.supernova().services.list()[:2]
+          [<Service: nova-conductor>, <Service: nova-cert>]
+        """
+        def wrap(client_func):
+            if hasattr(cls, client_name):
+                raise ValueError(
+                    _("Can not register client: name already exists: %s")
+                    % client_name)
+            setattr(cls, client_name, cached(client_func))
+            return client_func
+
+        return wrap
