@@ -36,7 +36,7 @@ RALLY_PLUGINS_DIR=~/.rally/plugins
 
 mkdir -p $RALLY_PLUGINS_DIR
 if [ -d $PLUGINS_DIR ]; then
-    cp -r $PLUGINS_DIR/*.py $RALLY_PLUGINS_DIR
+    cp -r $PLUGINS_DIR/ $RALLY_PLUGINS_DIR
 fi
 
 if [ -d $EXTRA_DIR ]; then
@@ -48,7 +48,7 @@ fi
 env
 set -o pipefail
 
-rally use deployment --deployment devstack
+rally deployment use --deployment devstack
 rally deployment check
 rally show flavors
 rally show images
@@ -56,7 +56,7 @@ rally show networks
 rally show secgroups
 rally show keypairs
 
-rally -v task start --task $TASK $TASK_ARGS
+rally -v --rally-debug task start --task $TASK $TASK_ARGS
 
 mkdir -p rally-plot/extra
 python $BASE/new/rally/rally/ui/utils.py render\
