@@ -143,7 +143,7 @@ class TaskTestCase(unittest.TestCase):
         rally = utils.Rally()
         cfg = self._get_sample_task_config()
         config = utils.TaskConfig(cfg)
-        task_uuids = list()
+        task_uuids = []
         for i in range(3):
             res = rally("task start --task %s" % config.filename)
             for line in res.splitlines():
@@ -158,7 +158,7 @@ class TaskTestCase(unittest.TestCase):
         rally = utils.Rally()
         cfg = self._get_sample_task_config()
         config = utils.TaskConfig(cfg)
-        files = list()
+        files = []
         for i in range(3):
             rally("task start --task %s" % config.filename)
             path = "/tmp/task_%d.json" % i
@@ -231,6 +231,36 @@ class TaskTestCase(unittest.TestCase):
         self.assertRaises(utils.RallyCmdError,
                           rally, "task list --status not_existing_status")
 
+    def test_list_with_print_uuids_option(self):
+        rally = utils.Rally()
+        cfg = self._get_sample_task_config()
+        config = utils.TaskConfig(cfg)
+
+        # Validate against zero tasks
+        self.assertEqual("", rally("task list --uuids-only"))
+
+        # Validate against a single task
+        res = rally("task start --task %s" % config.filename)
+        task_uuids = []
+        for line in res.splitlines():
+            if "finished" in line:
+                task_uuids.append(line.split(" ")[1][:-1])
+        self.assertTrue(len(task_uuids))
+        self.assertIn(task_uuids[0],
+                      rally("task list --uuids-only --deployment MAIN"))
+
+        # Validate against multiple tasks
+        for i in range(2):
+            rally("task start --task %s" % config.filename)
+            self.assertIn("finished", rally("task list --deployment MAIN"))
+        res = rally("task list --uuids-only --deployment MAIN")
+        task_uuids = res.split()
+        self.assertEqual(3, len(task_uuids))
+        res = rally("task list --uuids-only --deployment MAIN "
+                    "--status finished")
+        for uuid in task_uuids:
+            self.assertIn(uuid, res)
+
     def test_validate_is_valid(self):
         rally = utils.Rally()
         cfg = self._get_sample_task_config()
@@ -545,3 +575,81 @@ class SLATestCase(unittest.TestCase):
         ]
         data = rally("task sla_check --json", getjson=True)
         self.assertEqual(expected, data)
+
+
+class SLAExtraFlagsTestCase(unittest.TestCase):
+
+    def test_abort_on_sla_fail(self):
+        rally = utils.Rally()
+        cfg = {
+            "Dummy.dummy_exception": [
+                {
+                    "args": {},
+                    "runner": {
+                        "type": "constant",
+                        "times": 5,
+                        "concurrency": 5
+                    },
+                    "sla": {
+                        "failure_rate": {"max": 0}
+                    }
+                }
+            ]}
+        config = utils.TaskConfig(cfg)
+        rally("task start --task %s --abort-on-sla-failure" % config.filename)
+        expected = [
+            {"benchmark": "Dummy.dummy_exception",
+             "criterion": "aborted_on_sla",
+             "detail": "Task was aborted due to SLA failure(s).",
+             "pos": 0, "status": "FAIL"},
+            {"benchmark": "Dummy.dummy_exception",
+             "criterion": "failure_rate",
+             "detail": mock.ANY,
+             "pos": 0, "status": "FAIL"}
+        ]
+        try:
+            rally("task sla_check --json", getjson=True)
+        except utils.RallyCmdError as expected_error:
+            self.assertEqual(json.loads(expected_error.output), expected)
+        else:
+            self.fail("`rally task sla_check` command should return non-zero "
+                      "exit code")
+
+    def _test_broken_context(self, runner):
+        rally = utils.Rally()
+        cfg = {
+            "Dummy.dummy": [
+                {
+                    "args": {},
+                    "runner": runner,
+                    "context": {
+                        "dummy_context": {"fail_setup": True}
+                    }
+                }
+            ]}
+        config = utils.TaskConfig(cfg)
+        rally("task start --task %s" % config.filename)
+        expected = [
+            {"benchmark": "Dummy.dummy",
+             "criterion": "something_went_wrong",
+             "detail": mock.ANY,
+             "pos": 0, "status": "FAIL"}
+        ]
+        try:
+            rally("task sla_check --json", getjson=True)
+        except utils.RallyCmdError as expected_error:
+            self.assertEqual(json.loads(expected_error.output), expected)
+        else:
+            self.fail("`rally task sla_check` command should return non-zero "
+                      "exit code")
+
+    def test_broken_context_with_constant_runner(self):
+        self._test_broken_context({"type": "constant",
+                                   "times": 5,
+                                   "concurrency": 5})
+
+    def test_broken_context_with_rps_runner(self):
+        self._test_broken_context({"type": "rps",
+                                   "times": 5,
+                                   "rps": 3,
+                                   "timeout": 6})
