@@ -13,6 +13,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from boto import exception as boto_exception
 import mock
 from neutronclient.common import exceptions as neutron_exceptions
 
@@ -81,6 +82,29 @@ class QuotaMixinTestCase(test.TestCase):
         self.assertEqual([quota.tenant_uuid], quota.list())
 
 
+class NovaServerTestCase(test.TestCase):
+
+    def test_delete(self):
+        server = resources.NovaServer()
+        server.raw_resource = mock.Mock()
+        server._manager = mock.Mock()
+        server.delete()
+
+        server._manager.return_value.delete.assert_called_once_with(
+            server.raw_resource.id)
+
+    def test_delete_locked(self):
+        server = resources.NovaServer()
+        server.raw_resource = mock.Mock()
+        setattr(server.raw_resource, "OS-EXT-STS:locked", True)
+        server._manager = mock.Mock()
+        server.delete()
+
+        server.raw_resource.unlock.assert_called_once_with()
+        server._manager.return_value.delete.assert_called_once_with(
+            server.raw_resource.id)
+
+
 class NovaSecurityGroupTestCase(test.TestCase):
 
     @mock.patch("%s.base.ResourceManager._manager" % BASE)
@@ -95,6 +119,90 @@ class NovaSecurityGroupTestCase(test.TestCase):
                                  resources.NovaSecurityGroup().list())
 
 
+class NovaFloatingIpsBulkTestCase(test.TestCase):
+
+    def test_id(self):
+        ip_range = resources.NovaFloatingIpsBulk()
+        ip_range.raw_resource = mock.MagicMock()
+        self.assertEqual(ip_range.raw_resource.address, ip_range.id())
+
+    @mock.patch("%s.base.ResourceManager._manager" % BASE)
+    def test_list(self, mock_manager):
+        ip_range = [mock.MagicMock(), mock.MagicMock(), mock.MagicMock()]
+        ip_range[0].pool = "a"
+        ip_range[1].pool = "rally_fip_pool_a"
+        ip_range[2].pool = "rally_fip_pool_b"
+
+        mock_manager().list.return_value = ip_range
+        self.assertEqual(ip_range[1:], resources.NovaFloatingIpsBulk().list())
+
+
+class EC2MixinTestCase(test.TestCase):
+
+    def get_ec2_mixin(self):
+        ec2 = resources.EC2Mixin()
+        ec2._service = "ec2"
+        return ec2
+
+    def test__manager(self):
+        ec2 = self.get_ec2_mixin()
+        ec2.user = mock.MagicMock()
+        self.assertEqual(ec2.user.ec2.return_value, ec2._manager())
+
+
+class EC2ServerTestCase(test.TestCase):
+
+    @mock.patch("%s.EC2Server._manager" % BASE)
+    def test_is_deleted(self, mock_manager):
+        raw_res1 = mock.MagicMock(state="terminated")
+        raw_res2 = mock.MagicMock(state="terminated")
+        resource = mock.MagicMock(id="test_id")
+        manager = resources.EC2Server(resource=resource)
+
+        mock_manager().get_only_instances.return_value = [raw_res1]
+        self.assertTrue(manager.is_deleted())
+
+        raw_res1.state = "running"
+        self.assertFalse(manager.is_deleted())
+
+        mock_manager().get_only_instances.return_value = [raw_res1, raw_res2]
+        self.assertFalse(manager.is_deleted())
+
+        raw_res1.state = "terminated"
+        self.assertTrue(manager.is_deleted())
+
+        mock_manager().get_only_instances.return_value = []
+        self.assertTrue(manager.is_deleted())
+
+    @mock.patch("%s.EC2Server._manager" % BASE)
+    def test_is_deleted_exceptions(self, mock_manager):
+        mock_manager.side_effect = [
+            boto_exception.EC2ResponseError(
+                status="fake", reason="fake",
+                body={"Error": {"Code": "fake_code"}}),
+            boto_exception.EC2ResponseError(
+                status="fake", reason="fake",
+                body={"Error": {"Code": "InvalidInstanceID.NotFound"}})
+        ]
+        manager = resources.EC2Server(resource=mock.MagicMock())
+        self.assertFalse(manager.is_deleted())
+        self.assertTrue(manager.is_deleted())
+
+    @mock.patch("%s.EC2Server._manager" % BASE)
+    def test_delete(self, mock_manager):
+        resource = mock.MagicMock(id="test_id")
+        manager = resources.EC2Server(resource=resource)
+        manager.delete()
+        mock_manager().terminate_instances.assert_called_once_with(
+            instance_ids=["test_id"])
+
+    @mock.patch("%s.EC2Server._manager" % BASE)
+    def test_list(self, mock_manager):
+        manager = resources.EC2Server()
+        mock_manager().get_only_instances.return_value = ["a", "b", "c"]
+        self.assertEqual(["a", "b", "c"], manager.list())
+
+
 class NeutronMixinTestCase(test.TestCase):
 
     def get_neutron_mixin(self):
@@ -275,3 +383,55 @@ class KeystoneMixinTestCase(test.TestCase):
 
         self.assertSequenceEqual(result[:2], keystone_mixin.list())
         mock_wrap().list_some_resource2s.assert_called_once_with()
+
+
+class SwiftMixinTestCase(test.TestCase):
+
+    def get_swift_mixin(self):
+        swift_mixin = resources.SwiftMixin()
+        swift_mixin._service = "swift"
+        return swift_mixin
+
+    def test_manager(self):
+        swift_mixin = self.get_swift_mixin()
+        swift_mixin.user = mock.MagicMock()
+        self.assertEqual(swift_mixin.user.swift.return_value,
+                         swift_mixin._manager())
+
+    def test_id(self):
+        swift_mixin = self.get_swift_mixin()
+        swift_mixin.raw_resource = mock.MagicMock()
+        self.assertEqual(swift_mixin.raw_resource, swift_mixin.id())
+
+    def test_delete(self):
+        swift_mixin = self.get_swift_mixin()
+        swift_mixin.user = mock.MagicMock()
+        swift_mixin._resource = "some_resource"
+        swift_mixin.raw_resource = mock.MagicMock()
+        swift_mixin.delete()
+        swift_mixin.user.swift().delete_some_resource.assert_called_once_with(
+            *swift_mixin.raw_resource)
+
+
+class SwiftObjectTestCase(test.TestCase):
+
+    @mock.patch("%s.SwiftMixin._manager" % BASE)
+    def test_list(self, mock_manager):
+        containers = [mock.MagicMock(), mock.MagicMock()]
+        objects = [mock.MagicMock(), mock.MagicMock(), mock.MagicMock()]
+        mock_manager().get_account.return_value = ("header", containers)
+        mock_manager().get_container.return_value = ("header", objects)
+        self.assertEqual(len(containers),
+                         len(resources.SwiftContainer().list()))
+        self.assertEqual(len(containers) * len(objects),
+                         len(resources.SwiftObject().list()))
+
+
+class SwiftContainerTestCase(test.TestCase):
+
+    @mock.patch("%s.SwiftMixin._manager" % BASE)
+    def test_list(self, mock_manager):
+        containers = [mock.MagicMock(), mock.MagicMock(), mock.MagicMock()]
+        mock_manager().get_account.return_value = ("header", containers)
+        self.assertEqual(len(containers),
+                         len(resources.SwiftContainer().list()))
