@@ -106,6 +106,27 @@ class NovaServersTestCase(test.TestCase):
         scenario._delete_server.assert_called_once_with(fake_server,
                                                         force=False)
 
+    def test_boot_lock_unlock_and_delete(self):
+        server = fakes.FakeServer()
+        image = fakes.FakeImage()
+        flavor = fakes.FakeFlavor()
+
+        scenario = servers.NovaServers()
+        scenario._boot_server = mock.Mock(return_value=server)
+        scenario._lock_server = mock.Mock(side_effect=lambda s: s.lock())
+        scenario._unlock_server = mock.Mock(side_effect=lambda s: s.unlock())
+        scenario._delete_server = mock.Mock(
+            side_effect=lambda s, **kwargs:
+                self.assertFalse(getattr(s, "OS-EXT-STS:locked", False)))
+
+        scenario.boot_lock_unlock_and_delete(image, flavor, fakearg="fakearg")
+
+        scenario._boot_server.assert_called_once_with(image, flavor,
+                                                      fakearg="fakearg")
+        scenario._lock_server.assert_called_once_with(server)
+        scenario._unlock_server.assert_called_once_with(server)
+        scenario._delete_server.assert_called_once_with(server, force=False)
+
     def test_validate_actions(self):
         actions = [{"hardd_reboot": 6}]
         scenario = servers.NovaServers()
@@ -193,6 +214,64 @@ class NovaServersTestCase(test.TestCase):
                                                       fakearg="fakearg")
         scenario._list_servers.assert_called_once_with(True)
 
+    def test_suspend_and_resume_server(self):
+        fake_server = object()
+
+        scenario = servers.NovaServers()
+        scenario._generate_random_name = mock.MagicMock(return_value="name")
+        scenario._boot_server = mock.MagicMock(return_value=fake_server)
+        scenario._suspend_server = mock.MagicMock()
+        scenario._resume_server = mock.MagicMock()
+        scenario._delete_server = mock.MagicMock()
+
+        scenario.suspend_and_resume_server("img", 0, fakearg="fakearg")
+
+        scenario._boot_server.assert_called_once_with("img", 0,
+                                                      fakearg="fakearg")
+
+        scenario._suspend_server.assert_called_once_with(fake_server)
+        scenario._resume_server.assert_called_once_with(fake_server)
+        scenario._delete_server.assert_called_once_with(fake_server,
+                                                        force=False)
+
+    def test_pause_and_unpause_server(self):
+        fake_server = object()
+
+        scenario = servers.NovaServers()
+        scenario._generate_random_name = mock.MagicMock(return_value="name")
+        scenario._boot_server = mock.MagicMock(return_value=fake_server)
+        scenario._pause_server = mock.MagicMock()
+        scenario._unpause_server = mock.MagicMock()
+        scenario._delete_server = mock.MagicMock()
+
+        scenario.pause_and_unpause_server("img", 0, fakearg="fakearg")
+
+        scenario._boot_server.assert_called_once_with("img", 0,
+                                                      fakearg="fakearg")
+
+        scenario._pause_server.assert_called_once_with(fake_server)
+        scenario._unpause_server.assert_called_once_with(fake_server)
+        scenario._delete_server.assert_called_once_with(fake_server,
+                                                        force=False)
+
+    def test_shelve_and_unshelve_server(self):
+        fake_server = mock.MagicMock()
+        scenario = servers.NovaServers()
+        scenario._boot_server = mock.MagicMock(return_value=fake_server)
+        scenario._shelve_server = mock.MagicMock()
+        scenario._unshelve_server = mock.MagicMock()
+        scenario._delete_server = mock.MagicMock()
+
+        scenario.shelve_and_unshelve_server("img", 0, fakearg="fakearg")
+
+        scenario._boot_server.assert_called_once_with("img", 0,
+                                                      fakearg="fakearg")
+
+        scenario._shelve_server.assert_called_once_with(fake_server)
+        scenario._unshelve_server.assert_called_once_with(fake_server)
+        scenario._delete_server.assert_called_once_with(fake_server,
+                                                        force=False)
+
     def test_list_servers(self):
         scenario = servers.NovaServers()
         scenario._list_servers = mock.MagicMock()
@@ -334,16 +413,20 @@ class NovaServersTestCase(test.TestCase):
         scenario = servers.NovaServers()
         scenario._generate_random_name = mock.MagicMock(return_value="name")
         scenario._boot_server = mock.MagicMock(return_value=fake_server)
+        scenario.sleep_between = mock.MagicMock()
         scenario._find_host_to_migrate = mock.MagicMock(
                                          return_value="host_name")
         scenario._live_migrate = mock.MagicMock()
         scenario._delete_server = mock.MagicMock()
 
-        scenario.boot_and_live_migrate_server("img", 0, fakearg="fakearg")
+        scenario.boot_and_live_migrate_server("img", 0, min_sleep=10,
+                                              max_sleep=20, fakearg="fakearg")
 
         scenario._boot_server.assert_called_once_with("img", 0,
                                                       fakearg="fakearg")
 
+        scenario.sleep_between.assert_called_once_with(10, 20)
+
         scenario._find_host_to_migrate.assert_called_once_with(fake_server)
 
         scenario._live_migrate.assert_called_once_with(fake_server,
@@ -357,6 +440,7 @@ class NovaServersTestCase(test.TestCase):
         scenario = servers.NovaServers()
         scenario._generate_random_name = mock.MagicMock(return_value="name")
         scenario._boot_server = mock.MagicMock(return_value=fake_server)
+        scenario.sleep_between = mock.MagicMock()
         scenario._find_host_to_migrate = mock.MagicMock(
                                          return_value="host_name")
         scenario._live_migrate = mock.MagicMock()
@@ -367,6 +451,8 @@ class NovaServersTestCase(test.TestCase):
         scenario._create_volume = mock.MagicMock(return_value=fake_volume)
 
         scenario.boot_server_from_volume_and_live_migrate("img", 0, 5,
+                                                          min_sleep=10,
+                                                          max_sleep=20,
                                                           fakearg="f")
 
         scenario._create_volume.assert_called_once_with(5, imageRef="img")
@@ -376,6 +462,8 @@ class NovaServersTestCase(test.TestCase):
             block_device_mapping={"vda": "volume_id:::1"},
             fakearg="f")
 
+        scenario.sleep_between.assert_called_once_with(10, 20)
+
         scenario._find_host_to_migrate.assert_called_once_with(fake_server)
 
         scenario._live_migrate.assert_called_once_with(fake_server,
@@ -393,6 +481,8 @@ class NovaServersTestCase(test.TestCase):
         scenario._attach_volume = mock.MagicMock()
         scenario._detach_volume = mock.MagicMock()
 
+        scenario.sleep_between = mock.MagicMock()
+
         scenario._find_host_to_migrate = mock.MagicMock(
                                          return_value="host_name")
         scenario._live_migrate = mock.MagicMock()
@@ -402,14 +492,21 @@ class NovaServersTestCase(test.TestCase):
         scenario._create_volume = mock.MagicMock(return_value=fake_volume)
         scenario._delete_volume = mock.MagicMock()
 
+        image = "img"
+        flavor = "flavor"
+        size = 5
+        boot_kwargs = {"some_var": "asd"}
         scenario.boot_server_attach_created_volume_and_live_migrate(
-            "img",
-            0,
-            5)
+            image, flavor, size, min_sleep=10, max_sleep=20,
+            boot_server_kwargs=boot_kwargs)
+        scenario._boot_server.assert_called_once_with(image, flavor,
+                                                      **boot_kwargs)
+        scenario._create_volume.assert_called_once_with(size)
         scenario._attach_volume.assert_called_once_with(fake_server,
                                                         fake_volume)
         scenario._detach_volume.assert_called_once_with(fake_server,
                                                         fake_volume)
+        scenario.sleep_between.assert_called_once_with(10, 20)
         scenario._live_migrate.assert_called_once_with(fake_server,
                                                        "host_name",
                                                        False, False)
@@ -455,3 +552,41 @@ class NovaServersTestCase(test.TestCase):
 
     def test_boot_and_migrate_server_with_revert(self):
         self._test_boot_and_migrate_server(confirm=False)
+
+    def test_boot_and_rebuild_server(self):
+        scenario = servers.NovaServers()
+        scenario._boot_server = mock.Mock()
+        scenario._rebuild_server = mock.Mock()
+        scenario._delete_server = mock.Mock()
+
+        from_image = "img1"
+        to_image = "img2"
+        flavor = "flavor"
+        scenario.boot_and_rebuild_server(from_image, to_image, flavor,
+                                         fakearg="fakearg")
+
+        scenario._boot_server.assert_called_once_with(from_image, flavor,
+                                                      fakearg="fakearg")
+        server = scenario._boot_server.return_value
+        scenario._rebuild_server.assert_called_once_with(server, to_image)
+        scenario._delete_server.assert_called_once_with(server)
+
+    @mock.patch(NOVA_SERVERS_MODULE + ".network_wrapper.wrap")
+    def test_boot_and_associate_floating_ip(self, mock_wrap):
+        scenario = servers.NovaServers()
+        server = mock.Mock()
+        scenario._boot_server = mock.Mock(return_value=server)
+        scenario._associate_floating_ip = mock.Mock()
+
+        image = "img"
+        flavor = "flavor"
+        scenario.boot_and_associate_floating_ip(image, flavor,
+                                                fakearg="fakearg")
+
+        scenario._boot_server.assert_called_once_with(image, flavor,
+                                                      fakearg="fakearg")
+        net_wrap = mock_wrap.return_value
+        net_wrap.create_floating_ip.assert_called_once_with(
+            tenant_id=server.tenant_id)
+        scenario._associate_floating_ip.assert_called_once_with(
+            server, net_wrap.create_floating_ip.return_value["ip"])
