@@ -235,6 +235,66 @@ class NovaScenarioTestCase(test.TestCase):
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
                                        "nova.suspend_server")
 
+    def test__resume_server(self):
+        nova_scenario = utils.NovaScenario()
+        nova_scenario._resume_server(self.server)
+        self.server.resume.assert_called_once_with()
+        self._test_assert_called_once_with(
+            self.wait_for.mock, self.server,
+            CONF.benchmark.nova_server_resume_poll_interval,
+            CONF.benchmark.nova_server_resume_timeout)
+        self.res_is.mock.assert_has_calls([mock.call("ACTIVE")])
+        self._test_atomic_action_timer(nova_scenario.atomic_actions(),
+                                       "nova.resume_server")
+
+    def test__pause_server(self):
+        nova_scenario = utils.NovaScenario()
+        nova_scenario._pause_server(self.server)
+        self.server.pause.assert_called_once_with()
+        self._test_assert_called_once_with(
+            self.wait_for.mock, self.server,
+            CONF.benchmark.nova_server_pause_poll_interval,
+            CONF.benchmark.nova_server_pause_timeout)
+        self.res_is.mock.assert_has_calls([mock.call("PAUSED")])
+        self._test_atomic_action_timer(nova_scenario.atomic_actions(),
+                                       "nova.pause_server")
+
+    def test__unpause_server(self):
+        nova_scenario = utils.NovaScenario()
+        nova_scenario._unpause_server(self.server)
+        self.server.unpause.assert_called_once_with()
+        self._test_assert_called_once_with(
+            self.wait_for.mock, self.server,
+            CONF.benchmark.nova_server_unpause_poll_interval,
+            CONF.benchmark.nova_server_unpause_timeout)
+        self.res_is.mock.assert_has_calls([mock.call("ACTIVE")])
+        self._test_atomic_action_timer(nova_scenario.atomic_actions(),
+                                       "nova.unpause_server")
+
+    def test__shelve_server(self):
+        nova_scenario = utils.NovaScenario()
+        nova_scenario._shelve_server(self.server)
+        self.server.shelve.assert_called_once_with()
+        self._test_assert_called_once_with(
+            self.wait_for.mock, self.server,
+            CONF.benchmark.nova_server_shelve_poll_interval,
+            CONF.benchmark.nova_server_shelve_timeout)
+        self.res_is.mock.assert_has_calls([mock.call("SHELVED_OFFLOADED")])
+        self._test_atomic_action_timer(nova_scenario.atomic_actions(),
+                                       "nova.shelve_server")
+
+    def test__unshelve_server(self):
+        nova_scenario = utils.NovaScenario()
+        nova_scenario._unshelve_server(self.server)
+        self.server.unshelve.assert_called_once_with()
+        self._test_assert_called_once_with(
+            self.wait_for.mock, self.server,
+            CONF.benchmark.nova_server_unshelve_poll_interval,
+            CONF.benchmark.nova_server_unshelve_timeout)
+        self.res_is.mock.assert_has_calls([mock.call("ACTIVE")])
+        self._test_atomic_action_timer(nova_scenario.atomic_actions(),
+                                       "nova.unshelve_server")
+
     @mock.patch(NOVA_UTILS + ".NovaScenario.clients")
     def test__create_image(self, mock_clients):
         mock_clients("nova").images.get.return_value = self.image
@@ -297,6 +357,18 @@ class NovaScenarioTestCase(test.TestCase):
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
                                        "nova.soft_reboot_server")
 
+    def test__rebuild_server(self):
+        nova_scenario = utils.NovaScenario()
+        nova_scenario._rebuild_server(self.server, "img", fakearg="fakearg")
+        self.server.rebuild.assert_called_once_with("img", fakearg="fakearg")
+        self._test_assert_called_once_with(
+            self.wait_for.mock, self.server,
+            CONF.benchmark.nova_server_rebuild_poll_interval,
+            CONF.benchmark.nova_server_rebuild_timeout)
+        self.res_is.mock.assert_has_calls([mock.call("ACTIVE")])
+        self._test_atomic_action_timer(nova_scenario.atomic_actions(),
+                                       "nova.rebuild_server")
+
     def test__start_server(self):
         nova_scenario = utils.NovaScenario()
         nova_scenario._start_server(self.server)
@@ -345,52 +417,6 @@ class NovaScenarioTestCase(test.TestCase):
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
                                        "nova.unrescue_server")
 
-    @mock.patch(NOVA_UTILS + ".NovaScenario.clients")
-    def test__default_delete_all_servers(self, mock_clients):
-        mock_clients("nova").servers.list.return_value = [self.server,
-                                                          self.server1]
-        nova_scenario = utils.NovaScenario()
-        nova_scenario._delete_all_servers()
-        check_interval = CONF.benchmark.nova_server_delete_poll_interval
-        expected = [
-            mock.call(
-                self.server, update_resource=self.gfm(),
-                check_interval=check_interval,
-                timeout=CONF.benchmark.nova_server_delete_timeout
-            ),
-            mock.call(
-                self.server1, update_resource=self.gfm(),
-                check_interval=check_interval,
-                timeout=CONF.benchmark.nova_server_delete_timeout
-            )
-        ]
-        self.assertEqual(expected, self.wait_for_delete.mock.mock_calls)
-        self._test_atomic_action_timer(nova_scenario.atomic_actions(),
-                                       "nova.delete_all_servers")
-
-    @mock.patch(NOVA_UTILS + ".NovaScenario.clients")
-    def test__force_delete_all_servers(self, mock_clients):
-        mock_clients("nova").servers.list.return_value = [self.server,
-                                                          self.server1]
-        nova_scenario = utils.NovaScenario()
-        nova_scenario._delete_all_servers(force=True)
-        check_interval = CONF.benchmark.nova_server_delete_poll_interval
-        expected = [
-            mock.call(
-                self.server, update_resource=self.gfm(),
-                check_interval=check_interval,
-                timeout=CONF.benchmark.nova_server_delete_timeout
-            ),
-            mock.call(
-                self.server1, update_resource=self.gfm(),
-                check_interval=check_interval,
-                timeout=CONF.benchmark.nova_server_delete_timeout
-            )
-        ]
-        self.assertEqual(expected, self.wait_for_delete.mock.mock_calls)
-        self._test_atomic_action_timer(nova_scenario.atomic_actions(),
-                                       "nova.force_delete_all_servers")
-
     def test__delete_image(self):
         nova_scenario = utils.NovaScenario()
         nova_scenario._delete_image(self.image)
@@ -685,3 +711,65 @@ class NovaScenarioTestCase(test.TestCase):
             self.keypair)
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
                                        "nova.delete_keypair")
+
+    @mock.patch(NOVA_UTILS + ".NovaScenario.admin_clients")
+    def test__list_floating_ips_bulk(self, mock_clients):
+        floating_ips_bulk_list = ["foo_floating_ips_bulk"]
+        mock_clients("nova").floating_ips_bulk.list.return_value = (
+            floating_ips_bulk_list)
+        nova_scenario = utils.NovaScenario()
+        return_floating_ips_bulk_list = nova_scenario._list_floating_ips_bulk()
+        self.assertEqual(floating_ips_bulk_list, return_floating_ips_bulk_list)
+        self._test_atomic_action_timer(nova_scenario.atomic_actions(),
+                                       "nova.list_floating_ips_bulk")
+
+    @mock.patch(NOVA_UTILS + ".network_wrapper.generate_cidr")
+    @mock.patch(NOVA_UTILS + ".NovaScenario.admin_clients")
+    def test__create_floating_ips_bulk(self, mock_clients, mock_gencidr):
+        fake_cidr = "10.2.0.0/24"
+        fake_pool = "test1"
+        fake_floating_ips_bulk = mock.MagicMock()
+        fake_floating_ips_bulk.ip_range = fake_cidr
+        fake_floating_ips_bulk.pool = fake_pool
+        mock_clients("nova").floating_ips_bulk.create.return_value = (
+            fake_floating_ips_bulk)
+        nova_scenario = utils.NovaScenario()
+        return_iprange = nova_scenario._create_floating_ips_bulk(fake_cidr)
+        mock_gencidr.assert_called_once_with(start_cidr=fake_cidr)
+        self.assertEqual(return_iprange, fake_floating_ips_bulk)
+        self._test_atomic_action_timer(nova_scenario.atomic_actions(),
+                                       "nova.create_floating_ips_bulk")
+
+    @mock.patch(NOVA_UTILS + ".NovaScenario.admin_clients")
+    def test__delete_floating_ips_bulk(self, mock_clients):
+        fake_cidr = "10.2.0.0/24"
+        nova_scenario = utils.NovaScenario()
+        nova_scenario._delete_floating_ips_bulk(fake_cidr)
+        mock_clients("nova").floating_ips_bulk.delete.assert_called_once_with(
+            fake_cidr)
+        self._test_atomic_action_timer(nova_scenario.atomic_actions(),
+                                       "nova.delete_floating_ips_bulk")
+
+    @mock.patch(NOVA_UTILS + ".NovaScenario.admin_clients")
+    def test__list_hypervisors(self, mock_clients):
+        nova_scenario = utils.NovaScenario()
+        nova_scenario._list_hypervisors(detailed=False)
+        mock_clients("nova").hypervisors.list.assert_called_once_with(False)
+        self._test_atomic_action_timer(nova_scenario.atomic_actions(),
+                                       "nova.list_hypervisors")
+
+    def test__lock_server(self):
+        server = mock.Mock()
+        nova_scenario = utils.NovaScenario()
+        nova_scenario._lock_server(server)
+        server.lock.assert_called_once_with()
+        self._test_atomic_action_timer(nova_scenario.atomic_actions(),
+                                       "nova.lock_server")
+
+    def test__unlock_server(self):
+        server = mock.Mock()
+        nova_scenario = utils.NovaScenario()
+        nova_scenario._unlock_server(server)
+        server.unlock.assert_called_once_with()
+        self._test_atomic_action_timer(nova_scenario.atomic_actions(),
+                                       "nova.unlock_server")
