@@ -84,14 +84,34 @@ class VMScenarioTestCase(test.TestCase):
         vm_scenario = utils.VMScenario()
         vm_scenario.context = {"user": {"keypair": {"private": "ssh"}}}
         vm_scenario._run_command("1.2.3.4", 22, "username",
-                                 "password", "int", "script")
+                                 "password", "int", "/path/to/foo/script.sh",
+                                 is_file=True)
 
         mock_ssh_class.assert_called_once_with("username", "1.2.3.4", port=22,
                                                pkey="ssh",
                                                password="password")
         mock_ssh_instance.wait.assert_called_once_with()
         mock_run_command_over_ssh.assert_called_once_with(
-            mock_ssh_instance, "int", "script")
+            mock_ssh_instance, "int", "/path/to/foo/script.sh", True)
+
+    @mock.patch(VMTASKS_UTILS + ".sshutils.SSH")
+    def test__run_command_inline_script(self, mock_ssh):
+        mock_ssh_instance = mock.MagicMock()
+        mock_ssh.return_value = mock_ssh_instance
+        mock_ssh_instance.execute.return_value = "foobar"
+        vm_scenario = utils.VMScenario()
+        vm_scenario._wait_for_ssh = mock.Mock()
+        vm_scenario.context = {"user": {"keypair": {"private": "foo_pkey"}}}
+        result = vm_scenario._run_command("foo_ip", "foo_port", "foo_username",
+                                          "foo_password", "foo_interpreter",
+                                          "foo_script", is_file=False)
+        mock_ssh.assert_called_once_with("foo_username", "foo_ip",
+                                         port="foo_port", pkey="foo_pkey",
+                                         password="foo_password")
+        vm_scenario._wait_for_ssh.assert_called_once_with(mock_ssh_instance)
+        mock_ssh_instance.execute.assert_called_once_with("foo_interpreter",
+                                                          stdin="foo_script")
+        self.assertEqual(result, "foobar")
 
     @mock.patch(VMTASKS_UTILS + ".sys")
     @mock.patch("subprocess.Popen")
@@ -162,15 +182,13 @@ class VMScenarioTestCase(test.TestCase):
         ping_process.wait.assert_called_once_with()
 
     def get_scenario(self):
-
         server = mock.Mock(
             networks={"foo_net": "foo_data"},
-            addresses={"foo_net": [{"addr": "foo_addr"}]},
+            addresses={"foo_net": [{"addr": "foo_ip"}]},
             tenant_id="foo_tenant"
         )
         scenario = utils.VMScenario(context={})
 
-        scenario._netwrap = mock.Mock()
         scenario._boot_server = mock.Mock(return_value=server)
         scenario._delete_server = mock.Mock()
         scenario._associate_floating_ip = mock.Mock()
@@ -178,70 +196,87 @@ class VMScenarioTestCase(test.TestCase):
 
         return scenario, server
 
-    @mock.patch(VMTASKS_UTILS + ".network_wrapper")
-    def test__get_netwrap(self, mock_wrap):
-        scenario = utils.VMScenario(context={})
-        scenario.clients = "clients"
-        mock_wrap.wrap.return_value = "wrap"
-
-        ret = scenario._get_netwrap()
-
-        self.assertEqual("wrap", ret)
-
-        mock_wrap.wrap.assert_called_once_with("clients")
-
-    def test__boot_server_with_fip_missed_networks(self):
+    def test__boot_server_with_fip_without_networks(self):
         scenario, server = self.get_scenario()
-
         server.networks = {}
-
         self.assertRaises(RuntimeError,
                           scenario._boot_server_with_fip,
-                          "foo_image", "foo_flavor",
-                          foo_arg="foo_value")
-
+                          "foo_image", "foo_flavor", foo_arg="foo_value")
         scenario._boot_server.assert_called_once_with(
               "foo_image", "foo_flavor",
               foo_arg="foo_value", auto_assign_nic=True)
 
+    def test__boot_server_with_fixed_ip(self):
+        scenario, server = self.get_scenario()
+        scenario._attach_floating_ip = mock.Mock()
+        server, ip = scenario._boot_server_with_fip(
+            "foo_image", "foo_flavor", floating_network="ext_network",
+            use_floating_ip=False, wait_for_ping=True, foo_arg="foo_value")
+
+        self.assertEqual(ip, {"ip": "foo_ip", "id": None,
+                              "is_floating": False})
+        scenario._boot_server.assert_called_once_with(
+            "foo_image", "foo_flavor",
+            auto_assign_nic=True, foo_arg="foo_value")
+        self.assertEqual(scenario._attach_floating_ip.mock_calls, [])
+        scenario._wait_for_ping.assert_called_once_with("foo_ip")
+
     def test__boot_server_with_fip(self):
         scenario, server = self.get_scenario()
-
         scenario._attach_floating_ip = mock.Mock(
             return_value={"id": "foo_id", "ip": "foo_ip"})
-
-        scenario._boot_server_with_fip(
-            "foo_image", "foo_flavor",
-            wait_for_ping=True, foo_arg="foo_value",
-            floating_network="floating_network")
+        server, ip = scenario._boot_server_with_fip(
+            "foo_image", "foo_flavor", floating_network="ext_network",
+            use_floating_ip=True, wait_for_ping=True, foo_arg="foo_value")
+        self.assertEqual(ip, {"ip": "foo_ip", "id": "foo_id",
+                              "is_floating": True})
 
         scenario._boot_server.assert_called_once_with(
             "foo_image", "foo_flavor",
-            foo_arg="foo_value", auto_assign_nic=True)
-
+            auto_assign_nic=True, foo_arg="foo_value")
         scenario._attach_floating_ip.assert_called_once_with(
-            server, "floating_network")
+            server, "ext_network")
+        scenario._wait_for_ping.assert_called_once_with("foo_ip")
 
-        scenario._wait_for_ping.assert_called_once_with(
-            "foo_ip")
+    def test__delete_server_with_fixed_ip(self):
+        ip = {"ip": "foo_ip", "id": None, "is_floating": False}
+        scenario, server = self.get_scenario()
+        scenario._delete_floating_ip = mock.Mock()
+        scenario._delete_server_with_fip(server, ip, force_delete=True)
 
-    def test__attach_floating_ip(self):
+        self.assertEqual(scenario._delete_floating_ip.mock_calls, [])
+        scenario._delete_server.assert_called_once_with(server, force=True)
+
+    def test__delete_server_with_fip(self):
+        fip = {"ip": "foo_ip", "id": "foo_id", "is_floating": True}
+        scenario, server = self.get_scenario()
+        scenario._delete_floating_ip = mock.Mock()
+        scenario._delete_server_with_fip(server, fip, force_delete=True)
+
+        scenario._delete_floating_ip.assert_called_once_with(server, fip)
+        scenario._delete_server.assert_called_once_with(server, force=True)
+
+    @mock.patch(VMTASKS_UTILS + ".network_wrapper.wrap")
+    def test__attach_floating_ip(self, mock_wrap):
         scenario, server = self.get_scenario()
 
-        scenario._netwrap.create_floating_ip.return_value = {
+        netwrap = mock_wrap.return_value
+        netwrap.create_floating_ip.return_value = {
             "id": "foo_id", "ip": "foo_ip"}
 
         scenario._attach_floating_ip(
             server, floating_network="bar_network")
 
-        scenario._netwrap.create_floating_ip.assert_called_once_with(
+        mock_wrap.assert_called_once_with(scenario.clients)
+        netwrap.create_floating_ip.assert_called_once_with(
             ext_network="bar_network", int_network="foo_net",
-            tenant_id="foo_tenant", fixed_ip="foo_addr")
+            tenant_id="foo_tenant", fixed_ip="foo_ip")
 
         scenario._associate_floating_ip.assert_called_once_with(
-            server, "foo_ip", fixed_address="foo_addr")
+            server, "foo_ip", fixed_address="foo_ip")
 
-    def test__delete_floating_ip(self):
+    @mock.patch(VMTASKS_UTILS + ".network_wrapper.wrap")
+    def test__delete_floating_ip(self, mock_wrap):
         scenario, server = self.get_scenario()
 
         _check_addr = mock.Mock(return_value=True)
@@ -256,18 +291,6 @@ class VMScenarioTestCase(test.TestCase):
         _check_addr.assert_called_once_with(server)
         scenario._dissociate_floating_ip.assert_called_once_with(
             server, "foo_ip")
-        scenario._netwrap.delete_floating_ip.assert_called_once_with(
+        mock_wrap.assert_called_once_with(scenario.clients)
+        mock_wrap.return_value.delete_floating_ip.assert_called_once_with(
             "foo_id", wait=True)
-
-    def test__delete_server_with_fip(self):
-        scenario, server = self.get_scenario()
-        scenario._delete_floating_ip = mock.Mock()
-
-        scenario._delete_server_with_fip(
-            server, "foo_fip", force_delete=True)
-
-        scenario._delete_floating_ip.assert_called_once_with(
-            server, "foo_fip")
-
-        scenario._delete_server.assert_called_once_with(
-            server, force=True)
