@@ -13,13 +13,17 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import os
+
 from glanceclient import exc as glance_exc
 import mock
 from novaclient import exceptions as nova_exc
+import six
 
 from rally.benchmark import validation
 from rally import consts
 from rally import exceptions
+import rally.osclients
 from rally.verification.tempest import tempest
 from tests.unit import test
 
@@ -101,21 +105,30 @@ class ValidatorsTestCase(test.TestCase):
         self.assertTrue(result.is_valid, result.msg)
 
     @mock.patch("rally.benchmark.validation.os.access")
-    def test_file_exists(self, mock_access):
+    def test__file_access_ok(self, mock_access):
         mock_access.return_value = True
-        validator = self._unwrap_validator(validation.file_exists,
-                                           param_name="p")
-        result = validator({"args": {"p": "test_file"}}, None, None)
+        result = validation._file_access_ok(
+            "foobar", os.R_OK, "p", False)
         self.assertTrue(result.is_valid, result.msg)
 
     @mock.patch("rally.benchmark.validation.os.access")
-    def test_file_exists_not_found(self, mock_access):
+    def test__file_access_not_found(self, mock_access):
         mock_access.return_value = False
-        validator = self._unwrap_validator(validation.file_exists,
-                                           param_name="p")
-        result = validator({"args": {"p": "test_file"}}, None, None)
+        result = validation._file_access_ok(
+            "foobar", os.R_OK, "p", False)
         self.assertFalse(result.is_valid, result.msg)
 
+    @mock.patch("rally.benchmark.validation._file_access_ok")
+    def test_file_exists(self, mock__file_access_ok):
+        mock__file_access_ok.return_value = "foobar"
+        validator = self._unwrap_validator(validation.file_exists,
+                                           param_name="p",
+                                           required=False)
+        result = validator({"args": {"p": "test_file"}}, None, None)
+        self.assertEqual("foobar", result)
+        mock__file_access_ok.assert_called_once_with(
+            "test_file", os.R_OK, "p", False)
+
     def test__get_validated_image_no_value_in_config(self):
         result = validation._get_validated_image({}, None, "non_existing")
         self.assertFalse(result[0].is_valid, result[0].msg)
@@ -614,3 +627,32 @@ class ValidatorsTestCase(test.TestCase):
         clients.nova.side_effect = ImportError
         result = validator({}, clients, None)
         self.assertFalse(result.is_valid, result.msg)
+
+    def test_required_cinder_services(self):
+        validator = self._unwrap_validator(
+                validation.required_cinder_services,
+                service_name=six.text_type("cinder-service"))
+
+        with mock.patch.object(rally.osclients.Clients, "cinder") as client:
+            fake_service = mock.Mock(binary="cinder-service", state="up")
+            cinder_client = mock.Mock()
+            services = mock.Mock()
+            services.list.return_value = [fake_service]
+            cinder_client.services = services
+            client.return_value = cinder_client
+
+            deployment = {"admin": {"auth_url": "fake_endpoint",
+                                    "username": "username",
+                                    "password": "password"}}
+            result = validator({}, None, deployment)
+            self.assertTrue(result.is_valid, result.msg)
+
+            fake_service.state = "down"
+            result = validator({}, None, deployment)
+            self.assertFalse(result.is_valid, result.msg)
+
+    def test_restricted_parameters(self):
+        validator = self._unwrap_validator(
+            validation.restricted_parameters, "param_name")
+        result = validator({"args": {}}, None, None)
+        self.assertTrue(result.is_valid, result.msg)
