@@ -91,20 +91,20 @@ class NovaNetworkWrapperTestCase(test.TestCase):
         self.assertEqual(service.list_networks(), "foo_list")
         service.client.networks.list.assert_called_once_with()
 
-    def test_get_floating_ip(self):
+    def test__get_floating_ip(self):
         wrap = self.get_wrapper()
         wrap.client.floating_ips.get.return_value = mock.Mock(id="foo_id",
                                                               ip="foo_ip")
-        fip = wrap.get_floating_ip("fip_id")
+        fip = wrap._get_floating_ip("fip_id")
         wrap.client.floating_ips.get.assert_called_once_with("fip_id")
-        self.assertEqual(fip, {"ip": "foo_ip", "id": "foo_id"})
+        self.assertEqual(fip, "foo_id")
 
         wrap.client.floating_ips.get.side_effect = (
             nova_exceptions.NotFound(""))
-        self.assertIsNone(wrap.get_floating_ip("fip_id"))
+        self.assertIsNone(wrap._get_floating_ip("fip_id"))
 
         self.assertRaises(exceptions.GetResourceNotFound,
-                          wrap.get_floating_ip, "fip_id", do_raise=True)
+                          wrap._get_floating_ip, "fip_id", do_raise=True)
 
     def test_create_floating_ip(self):
         wrap = self.get_wrapper()
@@ -127,18 +127,22 @@ class NovaNetworkWrapperTestCase(test.TestCase):
 
         def get_fip(*args, **kwargs):
             for i in fip_found:
-                return {"id": "fip_id"}
+                return "fip_id"
             raise exceptions.GetResourceNotFound
-        wrap.get_floating_ip = mock.Mock(side_effect=get_fip)
+        wrap._get_floating_ip = mock.Mock(side_effect=get_fip)
 
         wrap.delete_floating_ip("fip_id")
         wrap.client.floating_ips.delete.assert_called_once_with("fip_id")
-        self.assertFalse(wrap.get_floating_ip.called)
+        self.assertFalse(wrap._get_floating_ip.called)
 
         wrap.delete_floating_ip("fip_id", wait=True)
         self.assertEqual(
-            wrap.get_floating_ip.mock_calls,
-            [mock.call({"id": "fip_id"}, do_raise=True)] * 4)
+            [mock.call("fip_id", do_raise=True)] * 4,
+            wrap._get_floating_ip.mock_calls)
+
+    def test_supports_secgroup(self):
+        wrap = self.get_wrapper()
+        self.assertTrue(wrap.supports_security_group()[0])
 
 
 class NeutronWrapperTestCase(test.TestCase):
@@ -255,6 +259,7 @@ class NeutronWrapperTestCase(test.TestCase):
                                    "network_id": "foo_id",
                                    "tenant_id": "foo_tenant",
                                    "ip_version": service.SUBNET_IP_VERSION,
+                                   "dns_nameservers": ["8.8.8.8", "8.8.4.4"],
                                    "cidr": "cidr-%d" % i}})
              for i in range(subnets_num)])
 
@@ -292,7 +297,8 @@ class NeutronWrapperTestCase(test.TestCase):
                         "name": "foo_name",
                         "status": "foo_status"}}
         net = service.create_network("foo_tenant", add_router=True,
-                                     subnets_num=subnets_num)
+                                     subnets_num=subnets_num,
+                                     dns_nameservers=["foo_nameservers"])
         self.assertEqual(net, {"id": "foo_id",
                                "name": "foo_name",
                                "status": "foo_status",
@@ -309,6 +315,7 @@ class NeutronWrapperTestCase(test.TestCase):
                                    "network_id": "foo_id",
                                    "tenant_id": "foo_tenant",
                                    "ip_version": service.SUBNET_IP_VERSION,
+                                   "dns_nameservers": ["foo_nameservers"],
                                    "cidr": "foo_cidr"}})] * subnets_num)
         self.assertEqual(service.client.add_interface_router.mock_calls,
                          [mock.call("foo_router", {"subnet_id": "foo_subnet"})
@@ -318,6 +325,7 @@ class NeutronWrapperTestCase(test.TestCase):
         service = self.get_wrapper()
         service.client.list_dhcp_agent_hosting_networks.return_value = (
             {"agents": []})
+        service.client.list_ports.return_value = {"ports": []}
         service.client.delete_network.return_value = "foo_deleted"
         result = service.delete_network({"id": "foo_id", "router_id": None,
                                          "subnets": []})
@@ -331,12 +339,15 @@ class NeutronWrapperTestCase(test.TestCase):
         self.assertEqual(service.client.delete_subnet.mock_calls, [])
         service.client.delete_network.assert_called_once_with("foo_id")
 
-    def test_delete_network_with_dhcp_and_router_and_subnets(self):
+    def test_delete_network_with_dhcp_and_router_and_ports_and_subnets(self):
         service = self.get_wrapper()
         agents = ["foo_agent", "bar_agent"]
         subnets = ["foo_subnet", "bar_subnet"]
+        ports = ["foo_port", "bar_port"]
         service.client.list_dhcp_agent_hosting_networks.return_value = (
             {"agents": [{"id": agent_id} for agent_id in agents]})
+        service.client.list_ports.return_value = (
+            {"ports": [{"id": port_id} for port_id in ports]})
         service.client.delete_network.return_value = "foo_deleted"
         result = service.delete_network(
             {"id": "foo_id", "router_id": "foo_router", "subnets": subnets})
@@ -352,6 +363,8 @@ class NeutronWrapperTestCase(test.TestCase):
              for subnet_id in subnets])
         self.assertEqual(service.client.delete_router.mock_calls,
                          [mock.call("foo_router")])
+        self.assertEqual(service.client.delete_port.mock_calls,
+                         [mock.call(port_id) for port_id in ports])
         self.assertEqual(service.client.delete_subnet.mock_calls,
                          [mock.call(subnet_id) for subnet_id in subnets])
         service.client.delete_network.assert_called_once_with("foo_id")
@@ -439,6 +452,19 @@ class NeutronWrapperTestCase(test.TestCase):
             {"port": {"network_id": "foo_net",
                       "name": "random_name", "foo": "bar"}})
 
+    def test_supports_security_group(self):
+        wrap = self.get_wrapper()
+        wrap.client.list_extensions.return_value = (
+            {"extensions": [{"alias": "security-group"}]})
+        self.assertTrue(wrap.supports_security_group()[0])
+
+        wrap.client.list_extensions.return_value = (
+            {"extensions": [{"alias": "dummy-group"}]})
+        self.assertFalse(wrap.supports_security_group()[0])
+
+        wrap.client.list_extensions.return_value = {}
+        self.assertFalse(wrap.supports_security_group()[0])
+
 
 class FunctionsTestCase(test.TestCase):
 
