@@ -303,16 +303,19 @@ class TaskCommandsTestCase(test.TestCase):
                          mock_json.call_args[1])
         mock_get.assert_called_once_with(task_id)
 
+    @mock.patch("rally.cmd.commands.task.sys.stdout")
     @mock.patch("rally.cmd.commands.task.objects.Task.get")
-    def test_invalid_results(self, mock_get):
+    def test_results_no_data(self, mock_get, mock_stdout):
         task_id = "foo_task_id"
-        data = []
-        mock_results = mock.Mock(return_value=data)
+        mock_results = mock.Mock(return_value=[])
         mock_get.return_value = mock.Mock(get_results=mock_results)
 
         result = self.task.results(task_id)
         mock_get.assert_called_once_with(task_id)
         self.assertEqual(1, result)
+        expected_out = ("The task %s is still running, results will become"
+                        " available when it is finished." % task_id)
+        mock_stdout.write.assert_has_calls([mock.call(expected_out)])
 
     @mock.patch("rally.cmd.commands.task.jsonschema.validate",
                 return_value=None)
@@ -384,7 +387,7 @@ class TaskCommandsTestCase(test.TestCase):
                       "load_duration": 2.1,
                       "full_duration": 2.2}}]
 
-        results = list()
+        results = []
         for task_uuid in tasks:
             results.extend(
                 map(lambda x: {"key": x["key"],
@@ -504,6 +507,26 @@ class TaskCommandsTestCase(test.TestCase):
             mock_objects_list.return_value, headers,
             sortby_index=headers.index("created_at"))
 
+    @mock.patch("rally.cmd.commands.task.cliutils.print_list")
+    @mock.patch("rally.cmd.commands.task.envutils.get_global",
+                return_value="123456789")
+    @mock.patch("rally.cmd.commands.task.objects.Task.list",
+                return_value=[fakes.FakeTask(uuid="a",
+                                             created_at=date.datetime.now(),
+                                             updated_at=date.datetime.now(),
+                                             status="c",
+                                             tag="d",
+                                             deployment_name="some_name")])
+    def test_list_uuids_only(self, mock_objects_list, mock_default,
+                             mock_print_list):
+        self.task.list(status="running", uuids_only=True)
+        mock_objects_list.assert_called_once_with(
+            deployment=mock_default.return_value,
+            status=consts.TaskStatus.RUNNING)
+        mock_print_list.assert_called_once_with(
+            mock_objects_list.return_value, ["uuid"],
+            print_header=False, print_border=False)
+
     def test_list_wrong_status(self):
         self.assertEqual(1, self.task.list(deployment="fake",
                                            status="wrong non existing status"))
