@@ -13,8 +13,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from keystoneclient import exceptions as keystone_exc
 import mock
 from oslo_config import cfg
+from six import moves
 
 from rally.cmd import cliutils
 from rally.cmd.commands import deployment
@@ -52,6 +54,21 @@ class CliUtilsTestCase(test.TestCase):
         h1 = cliutils.make_header("msg", size=4, symbol="=")
         self.assertEqual(h1, "====\n msg\n====\n")
 
+    def test_make_table_header(self):
+        actual = cliutils.make_table_header("Response Times (sec)", 40)
+        expected = "\n".join(
+            ("+--------------------------------------+",
+             "|         Response Times (sec)         |",)
+        )
+        self.assertEqual(expected, actual)
+
+        actual = cliutils.make_table_header("Response Times (sec)", 39)
+        expected = "\n".join(
+            ("+-------------------------------------+",
+             "|        Response Times (sec)         |",)
+        )
+        self.assertEqual(expected, actual)
+
     def test_pretty_float_formatter_rounding(self):
         test_table_rows = {"test_header": 6.56565}
         self.__dict__.update(**test_table_rows)
@@ -79,6 +96,26 @@ class CliUtilsTestCase(test.TestCase):
 
         self.assertEqual(return_value, "n/a")
 
+    def test_process_keyestone_exc(self):
+
+        @cliutils.process_keystone_exc
+        def a(a):
+            if a == 1:
+                raise keystone_exc.Unauthorized()
+
+            if a == 2:
+                raise keystone_exc.AuthorizationFailure()
+
+            if a == 3:
+                raise keystone_exc.ConnectionRefused()
+
+            return a
+
+        self.assertEqual(1, a(1))
+        self.assertEqual(1, a(2))
+        self.assertEqual(1, a(3))
+        self.assertEqual(4, a(4))
+
     def test__methods_of_with_class(self):
         class fake_class(object):
             def public(self):
@@ -170,6 +207,171 @@ class CliUtilsTestCase(test.TestCase):
                            {"failure": FailuresCommands})
         self.assertEqual(1, ret)
 
+    def test_print_list(self):
+        class TestObj(object):
+            x = 1
+            y = 2
+            z = 3.142857142857143
+            aOrB = 3            # mixed case field
+
+        out = moves.StringIO()
+        cliutils.print_list([TestObj()], ["x", "y"],
+                            print_header=True,
+                            print_border=True,
+                            sortby_index=None,
+                            out=out)
+        self.assertEqual("+---+---+\n"
+                         "| x | y |\n"
+                         "+---+---+\n"
+                         "| 1 | 2 |\n"
+                         "+---+---+",
+                         out.getvalue().strip())
+
+        out = moves.StringIO()
+        formatter = cliutils.pretty_float_formatter("z", 5)
+        cliutils.print_list([TestObj()], ["z"],
+                            print_header=True,
+                            print_border=True,
+                            sortby_index=None,
+                            formatters={"z": formatter},
+                            out=out)
+        self.assertEqual("+---------+\n"
+                         "| z       |\n"
+                         "+---------+\n"
+                         "| 3.14286 |\n"
+                         "+---------+",
+                         out.getvalue().strip())
+
+        out = moves.StringIO()
+        cliutils.print_list([TestObj()], ["x"],
+                            print_header=True,
+                            print_border=True,
+                            out=out)
+        self.assertEqual("+---+\n"
+                         "| x |\n"
+                         "+---+\n"
+                         "| 1 |\n"
+                         "+---+",
+                         out.getvalue().strip())
+
+        out = moves.StringIO()
+        cliutils.print_list([TestObj()], ["x", "y"],
+                            print_header=True,
+                            print_border=True,
+                            out=out)
+        self.assertEqual("+---+---+\n"
+                         "| x | y |\n"
+                         "+---+---+\n"
+                         "| 1 | 2 |\n"
+                         "+---+---+",
+                         out.getvalue().strip())
+
+        out = moves.StringIO()
+        cliutils.print_list([TestObj()], ["x"],
+                            print_header=False,
+                            print_border=False,
+                            out=out)
+        self.assertEqual("1",
+                         out.getvalue().strip())
+
+        out = moves.StringIO()
+        cliutils.print_list([TestObj()], ["x", "y"],
+                            print_header=False,
+                            print_border=False,
+                            out=out)
+        self.assertEqual("1 2",
+                         out.getvalue().strip())
+
+        out = moves.StringIO()
+        cliutils.print_list([TestObj()], ["x"],
+                            print_header=True,
+                            print_border=False,
+                            out=out)
+        self.assertEqual("x \n1",
+                         out.getvalue().strip())
+
+        out = moves.StringIO()
+        cliutils.print_list([TestObj()], ["x", "y"],
+                            print_header=True,
+                            print_border=False,
+                            out=out)
+        self.assertEqual("x y \n1 2",
+                         out.getvalue().strip())
+
+        out = moves.StringIO()
+        cliutils.print_list([TestObj()], ["x"],
+                            print_header=False,
+                            print_border=True,
+                            out=out)
+        self.assertEqual("+--+\n"
+                         "|1 |\n"
+                         "+--+",
+                         out.getvalue().strip())
+
+        out = moves.StringIO()
+        cliutils.print_list([TestObj()], ["x", "y"],
+                            print_header=False,
+                            print_border=True,
+                            out=out)
+        self.assertEqual("+--+--+\n"
+                         "|1 |2 |\n"
+                         "+--+--+",
+                         out.getvalue().strip())
+
+        out = moves.StringIO()
+        cliutils.print_list([TestObj()], ["aOrB"],
+                            mixed_case_fields=["aOrB"],
+                            print_header=True,
+                            print_border=True,
+                            out=out)
+        self.assertEqual("+------+\n"
+                         "| aOrB |\n"
+                         "+------+\n"
+                         "| 3    |\n"
+                         "+------+",
+                         out.getvalue().strip())
+
+        out = moves.StringIO()
+        cliutils.print_list([TestObj()], ["aOrB"],
+                            mixed_case_fields=["aOrB"],
+                            print_header=False,
+                            print_border=True,
+                            out=out)
+        self.assertEqual("+--+\n"
+                         "|3 |\n"
+                         "+--+",
+                         out.getvalue().strip())
+
+        out = moves.StringIO()
+        cliutils.print_list([TestObj()], ["aOrB"],
+                            mixed_case_fields=["aOrB"],
+                            print_header=True,
+                            print_border=False,
+                            out=out)
+        self.assertEqual("aOrB \n"
+                         "3",
+                         out.getvalue().strip())
+
+        out = moves.StringIO()
+        cliutils.print_list([TestObj()], ["aOrB"],
+                            mixed_case_fields=["aOrB"],
+                            print_header=False,
+                            print_border=False,
+                            out=out)
+        self.assertEqual("3",
+                         out.getvalue().strip())
+
+        out = moves.StringIO()
+        self.assertRaisesRegexp(ValueError,
+                                "Field labels list.*has different number "
+                                "of elements than fields list",
+                                cliutils.print_list,
+                                [TestObj()],
+                                ["x"],
+                                field_labels=["x", "y"],
+                                sortby_index=None,
+                                out=out)
+
 
 class ValidateArgsTest(test.TestCase):
 
@@ -577,3 +779,9 @@ class ValidateArgsTest(test.TestCase):
     def test_static_method_with_default_missing_args4(self):
         self.assertRaises(cliutils.MissingArgs,
                           self._test_static_method_with_default, y=2, z=3)
+
+    def test_alias_decorator(self):
+        alias_fn = mock.Mock(name="alias_fn")
+        cmd_name = "test-command"
+        wrapped = cliutils.alias(cmd_name)
+        self.assertEqual(wrapped(alias_fn).alias, cmd_name)
