@@ -132,18 +132,6 @@ class ImportModulesTestCase(test.TestCase):
         utils.try_append_module("rally.common.version", modules)
         self.assertIn("rally.common.version", modules)
 
-    def test_try_append_broken_module(self):
-        modules = {}
-        self.assertRaises(ImportError,
-                          utils.try_append_module,
-                          "tests.unit.fixtures.import.broken",
-                          modules)
-
-    def test_import_modules_from_package(self):
-        utils.import_modules_from_package("tests.unit.fixtures.import.package")
-        self.assertIn("tests.unit.fixtures.import.package.a", sys.modules)
-        self.assertIn("tests.unit.fixtures.import.package.b", sys.modules)
-
 
 class LogTestCase(test.TestCase):
 
@@ -181,6 +169,36 @@ class LogTestCase(test.TestCase):
         mock_log.assert_called_once_with("Deprecated test "
                                          "(deprecated in Rally v0.0.1)")
 
+    def test_log_deprecated_args(self):
+        mock_log = mock.MagicMock()
+
+        @utils.log_deprecated_args("Deprecated test", "0.0.1", ("z",),
+                                   mock_log, once=True)
+        def some_method(x, y, z):
+            return x + y + z
+
+        self.assertEqual(some_method(2, 2, z=3), 7)
+        mock_log.assert_called_once_with(
+            "Deprecated test (args `z' deprecated in Rally v0.0.1)")
+
+        mock_log.reset_mock()
+        self.assertEqual(some_method(2, 2, z=3), 7)
+        self.assertFalse(mock_log.called)
+
+        @utils.log_deprecated_args("Deprecated test", "0.0.1", ("z",),
+                                   mock_log, once=False)
+        def some_method(x, y, z):
+            return x + y + z
+
+        self.assertEqual(some_method(2, 2, z=3), 7)
+        mock_log.assert_called_once_with(
+            "Deprecated test (args `z' deprecated in Rally v0.0.1)")
+
+        mock_log.reset_mock()
+        self.assertEqual(some_method(2, 2, z=3), 7)
+        mock_log.assert_called_once_with(
+            "Deprecated test (args `z' deprecated in Rally v0.0.1)")
+
 
 class LoadExtraModulesTestCase(test.TestCase):
 
@@ -350,7 +368,7 @@ class EditDistanceTestCase(test.TestCase):
 class TenantIteratorTestCase(test.TestCase):
 
     def test_iterate_per_tenant(self):
-        users = list()
+        users = []
         tenants_count = 2
         users_per_tenant = 5
         for tenant_id in range(tenants_count):
